#!/usr/bin/python3
"""
    GeckoLogStruct - A class to manage the LogStruct for 'InYT v63'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = "".join(chr(c) for c in [73, 68, 76, 69])
ACMCVD = 342
ACQFFT = "".join(chr(c) for c in [105, 110, 84, 67, 105, 112, 68, 101, 108, 97, 121])
AFIKJP = "".join(chr(c) for c in [80, 49, 76])
AHEOCT = "".join(chr(c) for c in [85, 100, 80, 51])
AIIDNI = 354
AIVEMV = "".join(chr(c) for c in [67, 70, 71, 50, 55])
AJVDQL = 351
AKQXPI = "".join(chr(c) for c in [65, 76, 76])
AKSTSE = "".join(chr(c) for c in [83, 79, 117, 116, 51, 67, 117, 114])
AMJMAO = "".join(
    chr(c)
    for c in [69, 120, 116, 80, 114, 111, 98, 101, 68, 101, 116, 101, 99, 116, 101, 100]
)
AOAWBS = 281
AONPYY = "".join(chr(c) for c in [70, 85, 76, 76])
ATDZXN = 321
AWBSIR = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 79, 118, 101, 114, 84, 101, 109, 112]
)
AXNCUG = 479
AZMKQT = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 50, 67, 117, 114])
BBEKBD = 452
BDFSRO = 454
BDJQRJ = "".join(chr(c) for c in [75, 54, 48, 48])
BEKBDF = "".join(chr(c) for c in [67, 70, 71, 53])
BHZVOA = "".join(chr(c) for c in [83, 79, 117, 116, 54, 67, 117, 114])
BIAMJM = "".join(
    chr(c) for c in [84, 101, 109, 112, 78, 111, 116, 86, 97, 108, 105, 100]
)
BJEUTO = 293
BJLOIN = "".join(chr(c) for c in [67, 70, 71, 49, 52])
BLKXSJ = 271
BMJVHF = 256
BQFYLJ = "".join(
    chr(c)
    for c in [
        72,
        80,
        67,
        82,
        101,
        115,
        72,
        101,
        97,
        116,
        101,
        114,
        82,
        101,
        113,
        117,
        101,
        115,
        116,
    ]
)
BQNRXC = "".join(chr(c) for c in [80, 97, 99, 107, 82, 101, 115, 101, 116])
BQSNQL = 350
BSIRYX = "".join(
    chr(c)
    for c in [83, 105, 100, 101, 72, 101, 97, 116, 105, 110, 103, 68, 101, 103, 71]
)
BSSUHB = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 73, 68])
BVWVUB = 288
BWJYKL = "".join(chr(c) for c in [83, 119, 109, 82, 105, 115, 107])
BXIBHZ = 332
BXTIAC = 309
BXYBQS = 284
BYGDSB = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
CBFEGZ = "".join(chr(c) for c in [76, 79, 87])
CCPQIP = "".join(chr(c) for c in [83, 84, 79, 80])
CGETIX = 333
CHWDAF = "".join(chr(c) for c in [83, 79, 117, 116, 49])
CMCVDS = "".join(chr(c) for c in [83, 79, 117, 116, 57, 67, 117, 114])
CPQIPO = "".join(chr(c) for c in [83, 84, 65, 82, 84])
CQBMJV = 317
CQFFTT = 311
CRHYUA = "".join(chr(c) for c in [76, 73])
CTTGCR = "".join(
    chr(c) for c in [70, 111, 114, 99, 101, 67, 104, 101, 99, 107, 70, 108, 111]
)
CVDSSR = "".join(chr(c) for c in [83, 79, 117, 116, 49, 48, 67, 117, 114])
CVYYPI = "".join(chr(c) for c in [68, 101, 97, 108, 101, 114, 79, 112, 116])
CWAONP = "".join(chr(c) for c in [85, 78, 76, 79, 67, 75])
CXQIEF = "".join(chr(c) for c in [79, 70, 70])
CYWONF = "".join(chr(c) for c in [67, 70, 71, 51, 48])
CZOLSI = "".join(
    chr(c)
    for c in [
        105,
        110,
        70,
        108,
        111,
        82,
        97,
        116,
        105,
        111,
        77,
        105,
        110,
        105,
        109,
        117,
        109,
    ]
)
DAFIKJ = "".join(chr(c) for c in [80, 49, 72])
DDPMXF = 458
DFSROG = "".join(chr(c) for c in [67, 70, 71, 55])
DGKEAK = "".join(chr(c) for c in [83, 79, 117, 116, 49, 67, 117, 114])
DJQRJJ = "".join(chr(c) for c in [105, 110, 84, 101, 114, 102, 97, 99, 101])
DKHTZB = "".join(chr(c) for c in [67, 70, 71, 50])
DMPSCT = "".join(
    chr(c) for c in [77, 79, 68, 69, 95, 49, 95, 65, 78, 68, 95, 50, 95, 70, 65, 73, 76]
)
DNIBXT = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
DNQGVU = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 84, 121, 112, 101])
DPMXFU = "".join(chr(c) for c in [67, 70, 71, 49, 49])
DQLAII = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        105,
        115,
        116,
        97,
        110,
        99,
        101,
        69,
        114,
        114,
    ]
)
DRXAIV = 473
DSBDJQ = "".join(chr(c) for c in [105, 110, 67, 108, 101, 97, 114])
DSSRUR = "".join(chr(c) for c in [83, 79, 117, 116, 49, 49, 67, 117, 114])
DUBSSU = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
DZXNQT = 322
EAKSTS = 328
ECVYYP = "".join(
    chr(c) for c in [73, 110, 115, 116, 97, 108, 108, 101, 114, 79, 112, 116]
)
EEZFET = 470
EFJTAC = "".join(chr(c) for c in [82, 69, 77, 79, 84, 69])
EFXQGL = "".join(chr(c) for c in [76, 79])
EGZUQE = "".join(chr(c) for c in [80, 51])
EJNIBX = "".join(chr(c) for c in [80, 82, 69, 83, 83, 85, 82, 69, 95, 69, 82, 82])
EKBDFS = 453
EKCWAO = "".join(chr(c) for c in [76, 111, 99, 107, 77, 111, 100, 101])
EKVKZI = "".join(chr(c) for c in [80, 49, 72, 83, 116, 117, 99, 107])
ELHBQN = 360
ELWUEU = "".join(chr(c) for c in [67, 70, 71, 49, 55])
EMCGET = 331
EMVCYW = 476
EOCTHB = "".join(chr(c) for c in [85, 100, 80, 53])
ETDRXA = 472
ETIXQV = 325
EUHNNX = "".join(chr(c) for c in [67, 70, 71, 49, 57])
EUTOPH = 294
EXLSXU = "".join(chr(c) for c in [66, 76])
EZFETD = "".join(chr(c) for c in [67, 70, 71, 50, 51])
FCRTFM = "".join(chr(c) for c in [54, 52, 75])
FEFJTA = "".join(chr(c) for c in [73, 78, 84, 69, 82, 78, 65, 76])
FEGZUQ = "".join(chr(c) for c in [80, 50])
FETDRX = "".join(chr(c) for c in [67, 70, 71, 50, 52])
FFTTID = 314
FIKJPU = "".join(chr(c) for c in [80, 50, 72])
FJBIAM = "".join(chr(c) for c in [72, 101, 97, 116, 105, 110, 103])
FMNHTB = "".join(chr(c) for c in [67, 69])
FSROGM = 455
FTHECV = 319
FTSIFJ = "".join(
    chr(c) for c in [82, 101, 97, 108, 83, 101, 116, 80, 111, 105, 110, 116, 71]
)
FTTIDU = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 78, 111, 70, 108, 111, 69, 114, 114]
)
FUBJLO = "".join(chr(c) for c in [67, 70, 71, 49, 51])
FWRKIN = "".join(chr(c) for c in [72, 69, 65, 84, 95, 79, 78])
FXQGLR = "".join(chr(c) for c in [72, 73])
FYLJUI = "".join(
    chr(c)
    for c in [72, 80, 67, 67, 104, 105, 108, 108, 82, 101, 113, 117, 101, 115, 116]
)
FZCZOL = "".join(chr(c) for c in [105, 110, 70, 108, 111, 82, 97, 116, 105, 111])
FZDGKE = "".join(chr(c) for c in [72, 84, 82])
GDSBDJ = "".join(chr(c) for c in [68, 74, 83, 52])
GETIXQ = "".join(chr(c) for c in [83, 79, 117, 116, 54])
GKEAKS = 327
GLRAHE = 4
GMDDPM = 457
GQPLSP = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 80, 117, 114, 103, 101]
)
GSELHB = 358
GTYIYW = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 118])
GVUNXN = "".join(chr(c) for c in [75, 52, 48, 48])
GYOUSP = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        69,
        114,
        114,
    ]
)
GZUQEX = "".join(chr(c) for c in [80, 52])
HBQNRX = 361
HBSKSO = "".join(chr(c) for c in [79, 78])
HBVWVU = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 108])
HBXIBH = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116])
HECVYY = "".join(chr(c) for c in [])
HEOCTH = "".join(chr(c) for c in [85, 100, 80, 52])
HFTHEC = "".join(chr(c) for c in [77, 101, 110, 117])
HIUSOO = 304
HNNXWE = "".join(chr(c) for c in [67, 70, 71, 50, 48])
HTBJEU = 291
HTZBBE = "".join(chr(c) for c in [67, 70, 71, 51])
HUGTYI = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 73, 68])
HUOJRJ = 363
HWDAFI = 320
HXEKVK = 283
HZVOAC = 340
IACQFF = "".join(chr(c) for c in [70, 76, 67, 69, 114, 114])
IAMJMA = 279
IBHZVO = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 50])
IBXTIA = "".join(
    chr(c) for c in [82, 104, 72, 114, 75, 105, 110, 78, 111, 70, 108, 111]
)
IBXYBQ = "".join(
    chr(c)
    for c in [
        72,
        116,
        114,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        66,
        121,
        80,
        119,
        114,
        77,
        110,
        103,
    ]
)
ICXQIE = "".join(chr(c) for c in [83, 79, 65, 75])
IDNIBX = "".join(chr(c) for c in [82, 104, 72, 119, 72, 76])
IDUBSS = "".join(chr(c) for c in [83, 108, 97, 118, 101, 72, 76, 69, 114, 114])
IEFXQG = 259
IFJBIA = 277
IGYOUS = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        79,
        84,
    ]
)
IHBXIB = "".join(chr(c) for c in [83, 79, 117, 116, 49, 50])
IIDNIB = "".join(
    chr(c) for c in [82, 104, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
IJUGSE = "".join(chr(c) for c in [73, 78, 86, 65, 76, 73, 68, 95, 84, 89, 80, 69])
IKFWRK = "".join(chr(c) for c in [72, 80, 67, 83, 116, 97, 116, 101])
IKJPUN = "".join(chr(c) for c in [80, 50, 76])
ILXWAJ = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 50, 72, 83, 116, 117, 99, 107]
)
INEJNI = "".join(
    chr(c) for c in [65, 77, 66, 73, 69, 78, 84, 95, 84, 69, 77, 80, 95, 69, 82, 82]
)
INELWU = "".join(chr(c) for c in [67, 70, 71, 49, 54])
IPIVLA = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        68,
        101,
        116,
        101,
        99,
        116,
        101,
        100,
        84,
        121,
        112,
        101,
    ]
)
IPMDMP = 374
IRYXBQ = "".join(
    chr(c) for c in [73, 110, 71, 114, 105, 100, 68, 101, 116, 101, 99, 116, 101, 100]
)
IUSOOQ = "".join(chr(c) for c in [85, 100, 76, 105, 103, 104, 116, 84, 105, 109, 101])
IUXFEF = 367
IVDNQG = "".join(chr(c) for c in [70, 117, 108, 108])
IVEMVC = 475
IVLASS = "".join(chr(c) for c in [78, 79, 84, 95, 73, 78, 83, 84, 65, 76, 76, 69, 68])
IYWSKW = 300
JEUTOP = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 108])
JHIUSO = "".join(chr(c) for c in [85, 100, 81, 117, 105, 101, 116, 84, 105, 109, 101])
JIGYOU = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 66, 121, 85, 68]
)
JJJVYF = "".join(chr(c) for c in [80, 97, 99, 107, 77, 101, 109, 82, 97, 110, 103, 101])
JJVYFC = 290
JLOINE = 462
JMAOAW = 280
JMCBFE = 261
JNIBXY = "".join(chr(c) for c in [79, 84, 72, 69, 82, 95, 69, 82, 82])
JPUNRJ = "".join(chr(c) for c in [80, 51, 76])
JQRJJJ = "".join(chr(c) for c in [105, 110, 84, 111, 117, 99, 104])
JRJHIU = "".join(chr(c) for c in [85, 100, 80, 117, 109, 112, 84, 105, 109, 101])
JTACCP = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
JUIKFW = "".join(chr(c) for c in [67, 72, 73, 76, 76])
JUTYEK = 5
JVDQLA = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116]
)
JVHFTH = 274
JVYFCR = "".join(chr(c) for c in [49, 54, 75])
JWMNZM = 380
JYKLGQ = "".join(chr(c) for c in [78, 79])
JYMOUN = 267
JZTATD = "".join(chr(c) for c in [65, 85, 88])
KBDFSR = "".join(chr(c) for c in [67, 70, 71, 54])
KCWAON = 310
KEAKST = "".join(chr(c) for c in [83, 79, 117, 116, 50, 67, 117, 114])
KFWRKI = 379
KHTZBB = 450
KINEJN = "".join(
    chr(c) for c in [67, 79, 73, 76, 95, 83, 69, 78, 83, 79, 82, 95, 69, 82, 82]
)
KJPUNR = "".join(chr(c) for c in [80, 51, 72])
KLGQPL = "".join(chr(c) for c in [69, 88, 84, 82, 69, 77, 69])
KMLOIJ = "".join(chr(c) for c in [75, 49, 48, 48])
KPHUOJ = 307
KQTDKH = 448
KQXPIC = "".join(chr(c) for c in [81, 117, 105, 101, 116, 83, 116, 97, 116, 101])
KSOKPH = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48])
KSTSEM = 329
KVKZIL = "".join(chr(c) for c in [80, 50, 72, 83, 116, 117, 99, 107])
KWIVDN = 316
KXSJWM = 272
KZILXW = "".join(chr(c) for c in [82, 101, 108, 97, 121, 83, 116, 117, 99, 107])
LAIIDN = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 77, 105, 115, 115, 105, 110, 103, 69, 114, 114]
)
LASSAK = "".join(chr(c) for c in [84, 82, 69, 65, 68, 77, 73, 76, 76])
LHBQNR = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 108])
LIUXFE = "".join(
    chr(c) for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 75, 101, 121]
)
LJUIKF = "".join(chr(c) for c in [72, 69, 65, 84])
LKXSJW = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        66,
        114,
        101,
        97,
        107,
        101,
        114,
        73,
        110,
        100,
        101,
        120,
    ]
)
LNMHXE = "".join(
    chr(c)
    for c in [84, 104, 101, 114, 109, 105, 115, 116, 97, 110, 99, 101, 69, 114, 114]
)
LOIJUG = "".join(chr(c) for c in [75, 54, 48, 48, 72, 69])
LOINEL = "".join(chr(c) for c in [67, 70, 71, 49, 53])
LRAHEO = "".join(chr(c) for c in [85, 100, 80, 50])
LSIPMD = 373
LSPFTS = "".join(chr(c) for c in [83, 119, 109, 65, 100, 99])
LSXUJU = "".join(chr(c) for c in [79, 51])
LWUEUH = 465
LXWAJV = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 72, 116, 114, 83, 116, 117, 99, 107]
)
MAOAWB = "".join(
    chr(c) for c in [80, 114, 111, 103, 69, 99, 111, 110, 65, 99, 116, 105, 118, 101]
)
MCBFEG = "".join(chr(c) for c in [72, 73, 71, 72])
MCGETI = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114, 67, 117, 114])
MCVDSS = 343
MDDPMX = "".join(chr(c) for c in [67, 70, 71, 49, 48])
MDMPSC = "".join(chr(c) for c in [77, 79, 68, 69, 95, 49, 95, 70, 65, 73, 76])
MFZDGK = 326
MHXEKV = "".join(chr(c) for c in [75, 105, 110, 80, 117, 109, 112, 79, 102, 102])
MJIGYO = "".join(chr(c) for c in [80, 117, 114, 103, 101])
MJMAOA = "".join(chr(c) for c in [67, 104, 101, 99, 107, 70, 108, 111])
MJVHFT = "".join(
    chr(c) for c in [83, 116, 105, 99, 107, 68, 101, 116, 101, 99, 116, 101, 100]
)
MKQTDK = "".join(chr(c) for c in [67, 70, 71, 48])
MLOIJU = "".join(chr(c) for c in [75, 56, 48, 48])
MNZMJI = 381
MOUNBL = 268
MPSCTT = "".join(
    chr(c)
    for c in [
        77,
        79,
        68,
        69,
        95,
        49,
        95,
        65,
        78,
        68,
        95,
        72,
        69,
        65,
        84,
        73,
        78,
        71,
        95,
        70,
        65,
        73,
        76,
    ]
)
MVCYWO = "".join(chr(c) for c in [67, 70, 71, 50, 57])
MXFUBJ = "".join(chr(c) for c in [67, 70, 71, 49, 50])
NBLKXS = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 78, 98, 79, 102, 80, 104, 97, 115, 101, 115]
)
NEJNIB = "".join(chr(c) for c in [69, 69, 49, 95, 69, 69, 50, 95, 69, 82, 82])
NELWUE = 464
NFZCZO = "".join(
    chr(c)
    for c in [
        105,
        110,
        70,
        108,
        111,
        80,
        114,
        101,
        115,
        115,
        117,
        114,
        101,
        83,
        119,
        68,
        101,
        116,
        101,
        99,
        116,
        101,
        100,
    ]
)
NHTBJE = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 73, 68])
NIBXTI = "".join(chr(c) for c in [82, 104, 82, 101, 103, 83, 108, 111, 112, 101])
NKMLOI = "".join(chr(c) for c in [75, 54, 48, 48, 76, 69])
NMHXEK = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 50]
)
NNXWEE = 468
NPYYLI = "".join(
    chr(c)
    for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 83, 116, 97, 116, 117, 115]
)
NQGVUN = 357
NQJYMO = "".join(
    chr(c) for c in [69, 99, 111, 110, 111, 109, 121, 65, 99, 99, 101, 115, 115]
)
NQLNMH = 383
NQTMFZ = "".join(chr(c) for c in [83, 79, 117, 116, 53])
NRJZTA = "".join(chr(c) for c in [66, 76, 79])
NRSJMC = "".join(chr(c) for c in [85, 100, 65, 117, 120, 84, 105, 109, 101])
NRXCHW = "".join(chr(c) for c in [45, 45, 45])
NXNKML = "".join(chr(c) for c in [75, 52])
NXWEEZ = "".join(chr(c) for c in [67, 70, 71, 50, 49])
NZMJIG = "".join(chr(c) for c in [67, 108, 101, 97, 110])
OACMCV = "".join(chr(c) for c in [83, 79, 117, 116, 56, 67, 117, 114])
OAWBSI = "".join(chr(c) for c in [69, 99, 111, 110, 65, 99, 116, 105, 118, 101])
OCTHBS = 258
OGMDDP = "".join(chr(c) for c in [67, 70, 71, 57])
OIHBXI = "".join(chr(c) for c in [83, 79, 117, 116, 49, 49])
OIJUGS = "".join(chr(c) for c in [75, 51, 48, 48])
OINELW = 463
OJRJHI = 370
OKPHUO = "".join(chr(c) for c in [85, 100, 76, 105])
OLSIPM = "".join(
    chr(c)
    for c in [
        105,
        110,
        70,
        108,
        111,
        82,
        97,
        116,
        105,
        111,
        77,
        97,
        120,
        105,
        109,
        117,
        109,
    ]
)
ONFZCZ = 479
OOQNRS = 306
OPHUGT = "".join(
    chr(c) for c in [80, 97, 99, 107, 83, 116, 97, 116, 117, 115, 76, 105, 98]
)
OQNRSJ = "".join(
    chr(c)
    for c in [85, 100, 87, 97, 116, 101, 114, 70, 97, 108, 108, 84, 105, 109, 101]
)
OUNBLK = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        67,
        111,
        110,
        102,
        105,
        103,
        73,
        110,
        100,
        101,
        120,
    ]
)
OUSPBW = "".join(
    chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101, 83, 117, 115, 112]
)
OUYNQJ = 264
PBWJYK = "".join(chr(c) for c in [83, 119, 109, 65, 99, 116, 105, 118, 101])
PFTSIF = "".join(chr(c) for c in [79, 118, 101, 114, 84, 101, 109, 112])
PHUGTY = 296
PHUOJR = "".join(chr(c) for c in [85, 100, 87, 97, 116, 101, 114, 102, 97, 108, 108])
PICXQI = "".join(chr(c) for c in [68, 82, 65, 73, 78])
PIVLAS = 385
PLSPFT = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 65, 99, 116, 105, 118, 101]
)
PMDMPS = "".join(chr(c) for c in [70, 76, 79, 87, 95, 79, 75])
PMXFUB = 459
POUYNQ = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 70, 105, 108, 116, 68, 117, 114]
)
PQIPOU = "".join(chr(c) for c in [78, 69, 87])
PSCTTG = "".join(chr(c) for c in [72, 69, 65, 84, 73, 78, 71, 95, 70, 65, 73, 76])
PUNRJZ = "".join(chr(c) for c in [80, 52, 72])
PYYLIU = 364
QBMJVH = "".join(chr(c) for c in [72, 111, 117, 114, 115])
QFFTTI = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
QFYLJU = "".join(
    chr(c) for c in [72, 80, 67, 72, 101, 97, 116, 82, 101, 113, 117, 101, 115, 116]
)
QGLRAH = 0
QGVUNX = "".join(chr(c) for c in [75, 50, 48, 48])
QIEFXQ = "".join(chr(c) for c in [85, 100, 80, 49])
QIPOUY = "".join(chr(c) for c in [65, 67, 84, 73, 86, 69])
QJYMOU = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 65, 99, 116, 105, 111, 110]
)
QLAIID = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        65,
        109,
        98,
        105,
        97,
        110,
        116,
        79,
        72,
        76,
        101,
        118,
        101,
        108,
        50,
    ]
)
QLNMHX = "".join(
    chr(c) for c in [84, 104, 101, 114, 109, 70, 117, 115, 101, 69, 114, 114]
)
QNRSJM = 362
QNRXCH = 376
QPLSPF = 353
QRJJJV = "".join(chr(c) for c in [105, 110, 89, 84])
QSNQLN = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        72,
        116,
        114,
        50,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        66,
        121,
        80,
        119,
        114,
        77,
        110,
        103,
    ]
)
QTDKHT = "".join(chr(c) for c in [67, 70, 71, 49])
QTMFZD = 324
QVXOIH = "".join(chr(c) for c in [83, 79, 117, 116, 56])
QXPICX = 257
RAHEOC = 2
RAZMKQ = 347
RJHIUS = 303
RJZTAT = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
RKINEJ = "".join(
    chr(c) for c in [73, 78, 86, 65, 76, 73, 68, 95, 82, 69, 81, 85, 69, 83, 84]
)
ROGMDD = 456
RSJMCB = 369
RTFMNH = "".join(chr(c) for c in [80, 97, 99, 107, 82, 101, 103, 105, 111, 110])
RURAZM = 346
RXAIVE = "".join(chr(c) for c in [67, 70, 71, 50, 54])
RXCHWD = "".join(chr(c) for c in [82, 69, 83, 69, 84])
RYXBQF = 384
SAKQXP = 386
SBDJQR = "".join(chr(c) for c in [105, 110, 88, 77])
SELHBQ = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 118])
SEMCGE = "".join(chr(c) for c in [83, 79, 117, 116, 53, 67, 117, 114])
SIFJBI = "".join(
    chr(c) for c in [68, 105, 115, 112, 108, 97, 121, 101, 100, 84, 101, 109, 112, 71]
)
SIPMDM = "".join(
    chr(c) for c in [105, 110, 70, 108, 111, 69, 114, 114, 111, 114, 84, 121, 112, 101]
)
SIRYXB = 377
SJMCBF = "".join(chr(c) for c in [80, 49])
SJWMNZ = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        79,
        110,
        122,
        101,
        110,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
SKSOKP = 1
SKWIVD = "".join(chr(c) for c in [80, 97, 99, 107, 76, 111, 103, 84, 114, 105, 103])
SNQLNM = "".join(
    chr(c)
    for c in [
        83,
        105,
        108,
        101,
        110,
        116,
        77,
        111,
        100,
        101,
        65,
        99,
        116,
        105,
        118,
        101,
    ]
)
SOKPHU = 308
SOOQNR = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48, 84, 105, 109, 101])
SPBWJY = "".join(chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101])
SPFTSI = 355
SROGMD = "".join(chr(c) for c in [67, 70, 71, 56])
SRURAZ = "".join(chr(c) for c in [83, 79, 117, 116, 49, 50, 67, 117, 114])
SSAKQX = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
    ]
)
SSRURA = 345
SSUHBV = 285
STSEMC = "".join(chr(c) for c in [83, 79, 117, 116, 52, 67, 117, 114])
SUHBVW = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 118])
SXUJUT = 3
TACCPQ = 263
TATDZX = "".join(chr(c) for c in [83, 79, 117, 116, 50])
TBJEUT = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 118])
TDKHTZ = 449
TDRXAI = "".join(chr(c) for c in [67, 70, 71, 50, 53])
TDZXNQ = "".join(chr(c) for c in [83, 79, 117, 116, 51])
TFMNHT = "".join(chr(c) for c in [85, 76])
TGCRHY = "".join(
    chr(c) for c in [105, 110, 70, 108, 111, 74, 117, 115, 116, 82, 101, 115, 101, 116]
)
THBSKS = "".join(chr(c) for c in [85, 100, 66, 76])
THECVY = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
TIDUBS = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 78, 111, 70, 108, 111, 69, 114, 114]
)
TIXQVX = "".join(chr(c) for c in [70, 97, 110])
TMFZDG = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114])
TOPHUG = 295
TSEMCG = 330
TSIFJB = 275
TTGCRH = 375
TTIDUB = 315
TYEKCW = "".join(chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108])
TYIYWS = 299
TZBBEK = 451
UAXNCU = 256
UBJLOI = 461
UBSSUH = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 82, 101, 103, 83, 108, 111, 112, 101]
)
UBYGDS = "".join(chr(c) for c in [105, 110, 88, 69])
UEUHNN = 466
UGSELH = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 73, 68])
UGTYIY = 297
UHBVWV = 287
UHNNXW = 467
UJUTYE = "".join(chr(c) for c in [77, 83, 84, 82, 95, 72, 69, 65, 84, 69, 82])
UNBLKX = 270
UNRJZT = "".join(chr(c) for c in [80, 52, 76])
UNXNKM = "".join(chr(c) for c in [75, 56])
UOJRJH = "".join(chr(c) for c in [85, 100, 65, 117, 120])
UQEXLS = 260
URAZMK = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 67, 117, 114])
USOOQN = 305
USPBWJ = 282
UTOPHU = "".join(
    chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 105, 103, 76, 105, 98]
)
UTYEKC = "".join(chr(c) for c in [83, 76, 86, 95, 72, 69, 65, 84, 69, 82])
UXFEFJ = "".join(
    chr(c) for c in [70, 105, 108, 116, 101, 114, 65, 99, 99, 101, 115, 115]
)
UYNQJY = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        68,
        117,
        114,
        80,
        101,
        114,
        68,
        97,
        121,
    ]
)
VCYWON = 477
VDQLAI = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        70,
        117,
        115,
        101,
        69,
        114,
        114,
    ]
)
VDSSRU = 344
VEMVCY = "".join(chr(c) for c in [67, 70, 71, 50, 56])
VHFTHE = 6
VKZILX = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 83, 116, 117, 99, 107])
VLASSA = "".join(chr(c) for c in [83, 87, 73, 77, 95, 69, 88, 69, 82, 67, 73, 83, 69])
VOACMC = 341
VUBYGD = "".join(chr(c) for c in [85, 110, 107, 110, 111, 119, 110])
VUNXNK = "".join(chr(c) for c in [75, 56, 53])
VWVUBY = "".join(chr(c) for c in [80, 97, 99, 107, 84, 121, 112, 101])
VXOIHB = "".join(chr(c) for c in [83, 79, 117, 116, 57])
VYFCRT = "".join(chr(c) for c in [51, 50, 75])
VYYPIP = "".join(
    chr(c) for c in [65, 99, 99, 101, 115, 115, 111, 114, 121, 79, 112, 116]
)
WAJVDQ = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 80, 117, 109, 112, 79, 102, 102]
)
WAONPY = "".join(chr(c) for c in [80, 65, 82, 84, 73, 65, 76])
WBSIRY = 352
WDAFIK = "".join(chr(c) for c in [78, 65])
WEEZFE = "".join(chr(c) for c in [67, 70, 71, 50, 50])
WIVDNQ = "".join(chr(c) for c in [82, 101, 115, 116, 114, 105, 99, 116, 101, 100])
WJYKLG = 313
WMNZMJ = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 79, 110, 122, 101, 110, 68, 117, 114]
)
WONFZC = "".join(chr(c) for c in [67, 70, 71, 51, 49])
WRKINE = "".join(chr(c) for c in [67, 72, 73, 76, 76, 95, 79, 78])
WSKWIV = 301
WUEUHN = "".join(chr(c) for c in [67, 70, 71, 49, 56])
WVUBYG = 289
XAIVEM = 474
XBQFYL = 378
XEKVKZ = "".join(chr(c) for c in [82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116])
XFEFJT = 262
XFUBJL = 460
XLSXUJ = "".join(chr(c) for c in [67, 80])
XNKMLO = "".join(chr(c) for c in [75, 53])
XNQTMF = 323
XOIHBX = "".join(chr(c) for c in [83, 79, 117, 116, 49, 48])
XPICXQ = "".join(chr(c) for c in [78, 79, 84, 95, 83, 69, 84])
XQVXOI = "".join(chr(c) for c in [83, 79, 117, 116, 55])
XSJWMN = "".join(chr(c) for c in [79, 110, 122, 101, 110, 65, 99, 99, 101, 115, 115])
XTIACQ = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 88, 84, 114, 105, 101, 115]
)
XUJUTY = "".join(chr(c) for c in [76, 49, 50, 48])
XWAJVD = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 108, 97, 121, 83, 116, 117, 99, 107]
)
XWEEZF = 469
XYBQSN = "".join(
    chr(c)
    for c in [
        72,
        116,
        114,
        50,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        66,
        121,
        80,
        119,
        114,
        77,
        110,
        103,
    ]
)
YBQSNQ = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        72,
        116,
        114,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        66,
        121,
        80,
        119,
        114,
        77,
        110,
        103,
    ]
)
YEKCWA = 7
YFCRTF = "".join(chr(c) for c in [52, 56, 75])
YGDSBD = "".join(chr(c) for c in [77, 73, 65])
YIYWSK = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 108])
YKLGQP = "".join(chr(c) for c in [77, 69, 68])
YLIUXF = 365
YLJUIK = "".join(chr(c) for c in [72, 80, 67, 65, 117, 116, 111, 77, 111, 100, 101])
YMOUNB = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 68, 117, 114]
)
YNQJYM = 266
YOUSPB = "".join(chr(c) for c in [67, 80, 79, 84])
YPIPIV = "".join(chr(c) for c in [83, 116, 105, 99, 107, 66, 97, 110, 107])
YUAXNC = 63
YWONFZ = 478
YWSKWI = "".join(
    chr(c)
    for c in [80, 97, 99, 107, 78, 117, 109, 98, 101, 114, 79, 102, 67, 111, 110, 102]
)
YXBQFY = "".join(
    chr(c)
    for c in [
        67,
        111,
        111,
        108,
        90,
        111,
        110,
        101,
        68,
        101,
        116,
        101,
        99,
        116,
        101,
        100,
    ]
)
YYLIUX = "".join(
    chr(c) for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 83, 101, 101, 100]
)
YYPIPI = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 83, 101, 108, 101, 99, 116]
)
ZBBEKB = "".join(chr(c) for c in [67, 70, 71, 52])
ZCQBMJ = "".join(chr(c) for c in [82, 104, 87, 97, 116, 101, 114, 84, 101, 109, 112])
ZCZOLS = 371
ZFETDR = 471
ZILXWA = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 49, 72, 83, 116, 117, 99, 107]
)
ZMJIGY = 273
ZMKQTD = 348
ZOLSIP = 372
ZUQEXL = "".join(chr(c) for c in [80, 53])
ZVOACM = "".join(chr(c) for c in [83, 79, 117, 116, 55, 67, 117, 114])
ZXNQTM = "".join(chr(c) for c in [83, 79, 117, 116, 52])
ASSAKQ = [IVLASS, VLASSA, LASSAK]
BFEGZU = [CXQIEF, MCBFEG, CBFEGZ]
BSKSOK = [CXQIEF, HBSKSO]
CRTFMN = [JVYFCR, VYFCRT, YFCRTF, FCRTFM]
CTHBSK = [CXQIEF, FXQGLR]
FJTACC = [FEFJTA, EFJTAC]
GCRHYU = []
HYUAXN = [
    QIEFXQ,
    LRAHEO,
    AHEOCT,
    HEOCTH,
    EOCTHB,
    THBSKS,
    KSOKPH,
    OKPHUO,
    PHUOJR,
    UOJRJH,
    JRJHIU,
    JHIUSO,
    IUSOOQ,
    SOOQNR,
    OQNRSJ,
    NRSJMC,
]
IPOUYN = [ACCPQI, CCPQIP, CPQIPO, PQIPOU, QIPOUY]
IXQVXO = [
    WDAFIK,
    DAFIKJ,
    AFIKJP,
    FIKJPU,
    IKJPUN,
    KJPUNR,
    JPUNRJ,
    PUNRJZ,
    UNRJZT,
    ZUQEXL,
    NRJZTA,
    XLSXUJ,
    LSXUJU,
    XUJUTY,
    HECVYY,
    HECVYY,
    TIXQVX,
    HECVYY,
    HECVYY,
    RJZTAT,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    TYEKCW,
    JZTATD,
]
JBIAMJ = [HECVYY, FJBIAM, FJBIAM, FJBIAM]
JUGSEL = [
    QGVUNX,
    GVUNXN,
    VUNXNK,
    UNXNKM,
    NXNKML,
    XNKMLO,
    NKMLOI,
    KMLOIJ,
    MLOIJU,
    HECVYY,
    HECVYY,
    HECVYY,
    LOIJUG,
    OIJUGS,
    IJUGSE,
]
LGQPLS = [JYKLGQ, EFXQGL, YKLGQP, FXQGLR, KLGQPL]
MNHTBJ = [TFMNHT, FMNHTB]
NIBXYB = [
    ACCPQI,
    FWRKIN,
    WRKINE,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    RKINEJ,
    KINEJN,
    INEJNI,
    NEJNIB,
    EJNIBX,
    JNIBXY,
]
ONPYYL = [CWAONP, WAONPY, AONPYY]
PIPIVL = [
    THECVY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    HECVYY,
    YPIPIV,
]
QEXLSX = [CXQIEF, MCBFEG]
RHYUAX = [
    SJMCBF,
    FEGZUQ,
    EGZUQE,
    GZUQEX,
    ZUQEXL,
    EXLSXU,
    XLSXUJ,
    LSXUJU,
    XUJUTY,
    UJUTYE,
    UTYEKC,
    TYEKCW,
    EKCWAO,
    NPYYLI,
    YYLIUX,
    LIUXFE,
    CRHYUA,
]
RJJJVY = [
    VUBYGD,
    UBYGDS,
    BYGDSB,
    YGDSBD,
    GDSBDJ,
    DSBDJQ,
    SBDJQR,
    BDJQRJ,
    DJQRJJ,
    JQRJJJ,
    QRJJJV,
]
SCTTGC = [PMDMPS, MDMPSC, DMPSCT, MPSCTT, PSCTTG]
TIACQF = [HECVYY, XTIACQ, XTIACQ, XTIACQ]
UIKFWR = [LJUIKF, JUIKFW]
VDNQGV = [WIVDNQ, IVDNQG]
XCHWDA = [NRXCHW, RXCHWD]
XIBHZV = [
    WDAFIK,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    XLSXUJ,
]
XQGLRA = [CXQIEF, EFXQGL, FXQGLR]
XQIEFX = [XPICXQ, PICXQI, ICXQIE, CXQIEF]
ZDGKEA = [
    WDAFIK,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    FZDGKE,
]
ZTATDZ = [
    WDAFIK,
    DAFIKJ,
    AFIKJP,
    FIKJPU,
    IKJPUN,
    KJPUNR,
    JPUNRJ,
    PUNRJZ,
    UNRJZT,
    ZUQEXL,
    NRJZTA,
    XLSXUJ,
    LSXUJU,
    XUJUTY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    RJZTAT,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    TYEKCW,
    JZTATD,
]


class GeckoLogStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return YUAXNC

    @property
    def begin(self):
        return UAXNCU

    @property
    def end(self):
        return AXNCUG

    @property
    def all_device_keys(self):
        return RHYUAX

    @property
    def user_demand_keys(self):
        return HYUAXN

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoTempStructAccessor(self.struct, ZCQBMJ, CQBMJV, None),
            QBMJVH: GeckoByteStructAccessor(self.struct, QBMJVH, BMJVHF, None),
            MJVHFT: GeckoBoolStructAccessor(self.struct, MJVHFT, JVHFTH, VHFTHE, None),
            HFTHEC: GeckoEnumStructAccessor(
                self.struct, HFTHEC, FTHECV, None, PIPIVL, None, None, None
            ),
            IPIVLA: GeckoEnumStructAccessor(
                self.struct, IPIVLA, PIVLAS, None, ASSAKQ, None, None, None
            ),
            SSAKQX: GeckoByteStructAccessor(self.struct, SSAKQX, SAKQXP, AKQXPI),
            KQXPIC: GeckoEnumStructAccessor(
                self.struct, KQXPIC, QXPICX, None, XQIEFX, None, None, AKQXPI
            ),
            QIEFXQ: GeckoEnumStructAccessor(
                self.struct, QIEFXQ, IEFXQG, QGLRAH, XQGLRA, None, GLRAHE, AKQXPI
            ),
            LRAHEO: GeckoEnumStructAccessor(
                self.struct, LRAHEO, IEFXQG, RAHEOC, XQGLRA, None, GLRAHE, AKQXPI
            ),
            AHEOCT: GeckoEnumStructAccessor(
                self.struct, AHEOCT, IEFXQG, GLRAHE, XQGLRA, None, GLRAHE, AKQXPI
            ),
            HEOCTH: GeckoEnumStructAccessor(
                self.struct, HEOCTH, IEFXQG, VHFTHE, XQGLRA, None, GLRAHE, AKQXPI
            ),
            EOCTHB: GeckoEnumStructAccessor(
                self.struct, EOCTHB, OCTHBS, QGLRAH, CTHBSK, None, RAHEOC, AKQXPI
            ),
            THBSKS: GeckoEnumStructAccessor(
                self.struct, THBSKS, OCTHBS, SKSOKP, BSKSOK, None, RAHEOC, AKQXPI
            ),
            KSOKPH: GeckoEnumStructAccessor(
                self.struct, KSOKPH, SOKPHU, None, BSKSOK, None, None, AKQXPI
            ),
            OKPHUO: GeckoEnumStructAccessor(
                self.struct, OKPHUO, KPHUOJ, None, CTHBSK, None, None, AKQXPI
            ),
            PHUOJR: GeckoEnumStructAccessor(
                self.struct, PHUOJR, HUOJRJ, None, BSKSOK, None, None, AKQXPI
            ),
            UOJRJH: GeckoEnumStructAccessor(
                self.struct, UOJRJH, OJRJHI, None, BSKSOK, None, None, AKQXPI
            ),
            JRJHIU: GeckoByteStructAccessor(self.struct, JRJHIU, RJHIUS, AKQXPI),
            JHIUSO: GeckoByteStructAccessor(self.struct, JHIUSO, HIUSOO, AKQXPI),
            IUSOOQ: GeckoByteStructAccessor(self.struct, IUSOOQ, USOOQN, AKQXPI),
            SOOQNR: GeckoByteStructAccessor(self.struct, SOOQNR, OOQNRS, AKQXPI),
            OQNRSJ: GeckoByteStructAccessor(self.struct, OQNRSJ, QNRSJM, AKQXPI),
            NRSJMC: GeckoByteStructAccessor(self.struct, NRSJMC, RSJMCB, AKQXPI),
            SJMCBF: GeckoEnumStructAccessor(
                self.struct, SJMCBF, JMCBFE, QGLRAH, BFEGZU, None, GLRAHE, None
            ),
            FEGZUQ: GeckoEnumStructAccessor(
                self.struct, FEGZUQ, JMCBFE, RAHEOC, BFEGZU, None, GLRAHE, None
            ),
            EGZUQE: GeckoEnumStructAccessor(
                self.struct, EGZUQE, JMCBFE, GLRAHE, BFEGZU, None, GLRAHE, None
            ),
            GZUQEX: GeckoEnumStructAccessor(
                self.struct, GZUQEX, JMCBFE, VHFTHE, BFEGZU, None, GLRAHE, None
            ),
            ZUQEXL: GeckoEnumStructAccessor(
                self.struct, ZUQEXL, UQEXLS, QGLRAH, QEXLSX, None, RAHEOC, None
            ),
            EXLSXU: GeckoEnumStructAccessor(
                self.struct, EXLSXU, UQEXLS, SKSOKP, BSKSOK, None, RAHEOC, None
            ),
            XLSXUJ: GeckoEnumStructAccessor(
                self.struct, XLSXUJ, UQEXLS, RAHEOC, BSKSOK, None, RAHEOC, None
            ),
            LSXUJU: GeckoEnumStructAccessor(
                self.struct, LSXUJU, UQEXLS, SXUJUT, BSKSOK, None, RAHEOC, None
            ),
            XUJUTY: GeckoEnumStructAccessor(
                self.struct, XUJUTY, UQEXLS, GLRAHE, BSKSOK, None, RAHEOC, None
            ),
            UJUTYE: GeckoEnumStructAccessor(
                self.struct, UJUTYE, UQEXLS, JUTYEK, BSKSOK, None, RAHEOC, None
            ),
            UTYEKC: GeckoEnumStructAccessor(
                self.struct, UTYEKC, UQEXLS, VHFTHE, BSKSOK, None, RAHEOC, None
            ),
            TYEKCW: GeckoEnumStructAccessor(
                self.struct, TYEKCW, UQEXLS, YEKCWA, BSKSOK, None, RAHEOC, None
            ),
            EKCWAO: GeckoEnumStructAccessor(
                self.struct, EKCWAO, KCWAON, None, ONPYYL, None, None, AKQXPI
            ),
            NPYYLI: GeckoEnumStructAccessor(
                self.struct, NPYYLI, PYYLIU, None, ONPYYL, None, None, None
            ),
            YYLIUX: GeckoWordStructAccessor(self.struct, YYLIUX, YLIUXF, None),
            LIUXFE: GeckoWordStructAccessor(self.struct, LIUXFE, IUXFEF, AKQXPI),
            UXFEFJ: GeckoEnumStructAccessor(
                self.struct, UXFEFJ, XFEFJT, QGLRAH, FJTACC, None, RAHEOC, AKQXPI
            ),
            JTACCP: GeckoEnumStructAccessor(
                self.struct, JTACCP, TACCPQ, None, IPOUYN, None, None, AKQXPI
            ),
            POUYNQ: GeckoTimeStructAccessor(self.struct, POUYNQ, OUYNQJ, AKQXPI),
            UYNQJY: GeckoByteStructAccessor(self.struct, UYNQJY, YNQJYM, AKQXPI),
            NQJYMO: GeckoEnumStructAccessor(
                self.struct, NQJYMO, XFEFJT, RAHEOC, FJTACC, None, RAHEOC, AKQXPI
            ),
            QJYMOU: GeckoEnumStructAccessor(
                self.struct, QJYMOU, JYMOUN, None, IPOUYN, None, None, AKQXPI
            ),
            YMOUNB: GeckoTimeStructAccessor(self.struct, YMOUNB, MOUNBL, AKQXPI),
            OUNBLK: GeckoByteStructAccessor(self.struct, OUNBLK, UNBLKX, AKQXPI),
            NBLKXS: GeckoByteStructAccessor(self.struct, NBLKXS, BLKXSJ, AKQXPI),
            LKXSJW: GeckoByteStructAccessor(self.struct, LKXSJW, KXSJWM, AKQXPI),
            XSJWMN: GeckoEnumStructAccessor(
                self.struct, XSJWMN, XFEFJT, SKSOKP, FJTACC, None, RAHEOC, AKQXPI
            ),
            SJWMNZ: GeckoEnumStructAccessor(
                self.struct, SJWMNZ, JWMNZM, None, IPOUYN, None, None, AKQXPI
            ),
            WMNZMJ: GeckoTimeStructAccessor(self.struct, WMNZMJ, MNZMJI, AKQXPI),
            NZMJIG: GeckoBoolStructAccessor(self.struct, NZMJIG, ZMJIGY, QGLRAH, None),
            MJIGYO: GeckoBoolStructAccessor(self.struct, MJIGYO, ZMJIGY, RAHEOC, None),
            JIGYOU: GeckoBoolStructAccessor(self.struct, JIGYOU, ZMJIGY, SXUJUT, None),
            IGYOUS: GeckoBoolStructAccessor(self.struct, IGYOUS, ZMJIGY, GLRAHE, None),
            GYOUSP: GeckoBoolStructAccessor(self.struct, GYOUSP, ZMJIGY, JUTYEK, None),
            YOUSPB: GeckoBoolStructAccessor(self.struct, YOUSPB, JVHFTH, RAHEOC, None),
            OUSPBW: GeckoBoolStructAccessor(self.struct, OUSPBW, USPBWJ, SXUJUT, None),
            SPBWJY: GeckoBoolStructAccessor(self.struct, SPBWJY, USPBWJ, JUTYEK, None),
            PBWJYK: GeckoBoolStructAccessor(self.struct, PBWJYK, USPBWJ, VHFTHE, None),
            BWJYKL: GeckoEnumStructAccessor(
                self.struct, BWJYKL, WJYKLG, None, LGQPLS, None, None, None
            ),
            GQPLSP: GeckoBoolStructAccessor(self.struct, GQPLSP, QPLSPF, JUTYEK, None),
            PLSPFT: GeckoBoolStructAccessor(self.struct, PLSPFT, QPLSPF, VHFTHE, None),
            LSPFTS: GeckoWordStructAccessor(self.struct, LSPFTS, SPFTSI, None),
            PFTSIF: GeckoBoolStructAccessor(self.struct, PFTSIF, JVHFTH, SKSOKP, None),
            FTSIFJ: GeckoTempStructAccessor(self.struct, FTSIFJ, TSIFJB, None),
            SIFJBI: GeckoTempStructAccessor(self.struct, SIFJBI, IFJBIA, None),
            FJBIAM: GeckoEnumStructAccessor(
                self.struct, FJBIAM, UQEXLS, JUTYEK, JBIAMJ, None, GLRAHE, None
            ),
            BIAMJM: GeckoBoolStructAccessor(self.struct, BIAMJM, IAMJMA, RAHEOC, None),
            AMJMAO: GeckoBoolStructAccessor(self.struct, AMJMAO, IAMJMA, VHFTHE, None),
            MJMAOA: GeckoBoolStructAccessor(self.struct, MJMAOA, JMAOAW, RAHEOC, None),
            MAOAWB: GeckoBoolStructAccessor(self.struct, MAOAWB, AOAWBS, SKSOKP, None),
            OAWBSI: GeckoBoolStructAccessor(
                self.struct, OAWBSI, AOAWBS, RAHEOC, AKQXPI
            ),
            AWBSIR: GeckoBoolStructAccessor(self.struct, AWBSIR, WBSIRY, SKSOKP, None),
            BSIRYX: GeckoByteStructAccessor(self.struct, BSIRYX, SIRYXB, None),
            IRYXBQ: GeckoBoolStructAccessor(self.struct, IRYXBQ, RYXBQF, QGLRAH, None),
            YXBQFY: GeckoBoolStructAccessor(self.struct, YXBQFY, XBQFYL, QGLRAH, None),
            BQFYLJ: GeckoBoolStructAccessor(self.struct, BQFYLJ, XBQFYL, GLRAHE, None),
            QFYLJU: GeckoBoolStructAccessor(self.struct, QFYLJU, XBQFYL, JUTYEK, None),
            FYLJUI: GeckoBoolStructAccessor(self.struct, FYLJUI, XBQFYL, VHFTHE, None),
            YLJUIK: GeckoEnumStructAccessor(
                self.struct, YLJUIK, XBQFYL, YEKCWA, UIKFWR, None, RAHEOC, AKQXPI
            ),
            IKFWRK: GeckoEnumStructAccessor(
                self.struct, IKFWRK, KFWRKI, None, NIBXYB, None, None, None
            ),
            IBXYBQ: GeckoBoolStructAccessor(self.struct, IBXYBQ, BXYBQS, QGLRAH, None),
            XYBQSN: GeckoBoolStructAccessor(self.struct, XYBQSN, BXYBQS, SKSOKP, None),
            YBQSNQ: GeckoBoolStructAccessor(self.struct, YBQSNQ, BQSNQL, QGLRAH, None),
            QSNQLN: GeckoBoolStructAccessor(self.struct, QSNQLN, BQSNQL, SKSOKP, None),
            SNQLNM: GeckoBoolStructAccessor(self.struct, SNQLNM, NQLNMH, QGLRAH, None),
            QLNMHX: GeckoBoolStructAccessor(self.struct, QLNMHX, JVHFTH, SXUJUT, None),
            LNMHXE: GeckoBoolStructAccessor(self.struct, LNMHXE, USPBWJ, QGLRAH, None),
            NMHXEK: GeckoBoolStructAccessor(self.struct, NMHXEK, USPBWJ, SKSOKP, None),
            MHXEKV: GeckoBoolStructAccessor(self.struct, MHXEKV, HXEKVK, RAHEOC, None),
            XEKVKZ: GeckoBoolStructAccessor(self.struct, XEKVKZ, HXEKVK, SXUJUT, None),
            EKVKZI: GeckoBoolStructAccessor(self.struct, EKVKZI, BXYBQS, SXUJUT, None),
            KVKZIL: GeckoBoolStructAccessor(self.struct, KVKZIL, BXYBQS, GLRAHE, None),
            VKZILX: GeckoBoolStructAccessor(self.struct, VKZILX, BXYBQS, JUTYEK, None),
            KZILXW: GeckoBoolStructAccessor(self.struct, KZILXW, BXYBQS, VHFTHE, None),
            ZILXWA: GeckoBoolStructAccessor(self.struct, ZILXWA, BQSNQL, SXUJUT, None),
            ILXWAJ: GeckoBoolStructAccessor(self.struct, ILXWAJ, BQSNQL, GLRAHE, None),
            LXWAJV: GeckoBoolStructAccessor(self.struct, LXWAJV, BQSNQL, JUTYEK, None),
            XWAJVD: GeckoBoolStructAccessor(self.struct, XWAJVD, BQSNQL, VHFTHE, None),
            WAJVDQ: GeckoBoolStructAccessor(self.struct, WAJVDQ, AJVDQL, RAHEOC, None),
            JVDQLA: GeckoBoolStructAccessor(self.struct, JVDQLA, AJVDQL, SXUJUT, None),
            VDQLAI: GeckoBoolStructAccessor(self.struct, VDQLAI, WBSIRY, SXUJUT, None),
            DQLAII: GeckoBoolStructAccessor(self.struct, DQLAII, QPLSPF, QGLRAH, None),
            QLAIID: GeckoBoolStructAccessor(self.struct, QLAIID, QPLSPF, SKSOKP, None),
            LAIIDN: GeckoBoolStructAccessor(self.struct, LAIIDN, AIIDNI, QGLRAH, None),
            IIDNIB: GeckoBoolStructAccessor(self.struct, IIDNIB, JMAOAW, QGLRAH, None),
            IDNIBX: GeckoBoolStructAccessor(self.struct, IDNIBX, HXEKVK, QGLRAH, None),
            DNIBXT: GeckoBoolStructAccessor(self.struct, DNIBXT, HXEKVK, SKSOKP, None),
            NIBXTI: GeckoBoolStructAccessor(self.struct, NIBXTI, HXEKVK, GLRAHE, None),
            IBXTIA: GeckoBoolStructAccessor(self.struct, IBXTIA, BXTIAC, QGLRAH, None),
            XTIACQ: GeckoEnumStructAccessor(
                self.struct, XTIACQ, BXTIAC, SKSOKP, TIACQF, None, GLRAHE, None
            ),
            IACQFF: GeckoBoolStructAccessor(self.struct, IACQFF, BXTIAC, SXUJUT, None),
            ACQFFT: GeckoWordStructAccessor(self.struct, ACQFFT, CQFFTT, None),
            QFFTTI: GeckoBoolStructAccessor(self.struct, QFFTTI, FFTTID, QGLRAH, None),
            FTTIDU: GeckoBoolStructAccessor(self.struct, FTTIDU, TTIDUB, QGLRAH, None),
            TIDUBS: GeckoBoolStructAccessor(self.struct, TIDUBS, TTIDUB, SKSOKP, None),
            IDUBSS: GeckoBoolStructAccessor(self.struct, IDUBSS, AJVDQL, QGLRAH, None),
            DUBSSU: GeckoBoolStructAccessor(self.struct, DUBSSU, AJVDQL, SKSOKP, None),
            UBSSUH: GeckoBoolStructAccessor(self.struct, UBSSUH, AJVDQL, GLRAHE, None),
            BSSUHB: GeckoWordStructAccessor(self.struct, BSSUHB, SSUHBV, None),
            SUHBVW: GeckoByteStructAccessor(self.struct, SUHBVW, UHBVWV, None),
            HBVWVU: GeckoByteStructAccessor(self.struct, HBVWVU, BVWVUB, None),
            VWVUBY: GeckoEnumStructAccessor(
                self.struct, VWVUBY, WVUBYG, None, RJJJVY, None, None, None
            ),
            JJJVYF: GeckoEnumStructAccessor(
                self.struct, JJJVYF, JJVYFC, QGLRAH, CRTFMN, None, GLRAHE, None
            ),
            RTFMNH: GeckoEnumStructAccessor(
                self.struct, RTFMNH, JJVYFC, RAHEOC, MNHTBJ, None, RAHEOC, None
            ),
            NHTBJE: GeckoWordStructAccessor(self.struct, NHTBJE, HTBJEU, None),
            TBJEUT: GeckoByteStructAccessor(self.struct, TBJEUT, BJEUTO, None),
            JEUTOP: GeckoByteStructAccessor(self.struct, JEUTOP, EUTOPH, None),
            UTOPHU: GeckoByteStructAccessor(self.struct, UTOPHU, TOPHUG, None),
            OPHUGT: GeckoByteStructAccessor(self.struct, OPHUGT, PHUGTY, None),
            HUGTYI: GeckoWordStructAccessor(self.struct, HUGTYI, UGTYIY, None),
            GTYIYW: GeckoByteStructAccessor(self.struct, GTYIYW, TYIYWS, None),
            YIYWSK: GeckoByteStructAccessor(self.struct, YIYWSK, IYWSKW, None),
            YWSKWI: GeckoWordStructAccessor(self.struct, YWSKWI, WSKWIV, None),
            SKWIVD: GeckoEnumStructAccessor(
                self.struct, SKWIVD, KWIVDN, None, VDNQGV, None, RAHEOC, AKQXPI
            ),
            DNQGVU: GeckoEnumStructAccessor(
                self.struct, DNQGVU, NQGVUN, None, JUGSEL, None, None, None
            ),
            UGSELH: GeckoWordStructAccessor(self.struct, UGSELH, GSELHB, None),
            SELHBQ: GeckoByteStructAccessor(self.struct, SELHBQ, ELHBQN, None),
            LHBQNR: GeckoByteStructAccessor(self.struct, LHBQNR, HBQNRX, None),
            BQNRXC: GeckoEnumStructAccessor(
                self.struct, BQNRXC, QNRXCH, None, XCHWDA, None, None, AKQXPI
            ),
            CHWDAF: GeckoEnumStructAccessor(
                self.struct, CHWDAF, HWDAFI, None, ZTATDZ, None, None, AKQXPI
            ),
            TATDZX: GeckoEnumStructAccessor(
                self.struct, TATDZX, ATDZXN, None, ZTATDZ, None, None, AKQXPI
            ),
            TDZXNQ: GeckoEnumStructAccessor(
                self.struct, TDZXNQ, DZXNQT, None, ZTATDZ, None, None, AKQXPI
            ),
            ZXNQTM: GeckoEnumStructAccessor(
                self.struct, ZXNQTM, XNQTMF, None, ZTATDZ, None, None, AKQXPI
            ),
            NQTMFZ: GeckoEnumStructAccessor(
                self.struct, NQTMFZ, QTMFZD, None, ZTATDZ, None, None, AKQXPI
            ),
            TMFZDG: GeckoEnumStructAccessor(
                self.struct, TMFZDG, MFZDGK, None, ZDGKEA, None, None, AKQXPI
            ),
            DGKEAK: GeckoByteStructAccessor(self.struct, DGKEAK, GKEAKS, AKQXPI),
            KEAKST: GeckoByteStructAccessor(self.struct, KEAKST, EAKSTS, AKQXPI),
            AKSTSE: GeckoByteStructAccessor(self.struct, AKSTSE, KSTSEM, AKQXPI),
            STSEMC: GeckoByteStructAccessor(self.struct, STSEMC, TSEMCG, AKQXPI),
            SEMCGE: GeckoByteStructAccessor(self.struct, SEMCGE, EMCGET, AKQXPI),
            MCGETI: GeckoByteStructAccessor(self.struct, MCGETI, CGETIX, AKQXPI),
            GETIXQ: GeckoEnumStructAccessor(
                self.struct, GETIXQ, ETIXQV, None, IXQVXO, None, None, AKQXPI
            ),
            XQVXOI: GeckoEnumStructAccessor(
                self.struct, XQVXOI, MFZDGK, None, IXQVXO, None, None, AKQXPI
            ),
            QVXOIH: GeckoEnumStructAccessor(
                self.struct, QVXOIH, GKEAKS, None, IXQVXO, None, None, AKQXPI
            ),
            VXOIHB: GeckoEnumStructAccessor(
                self.struct, VXOIHB, EAKSTS, None, IXQVXO, None, None, AKQXPI
            ),
            XOIHBX: GeckoEnumStructAccessor(
                self.struct, XOIHBX, KSTSEM, None, IXQVXO, None, None, AKQXPI
            ),
            OIHBXI: GeckoEnumStructAccessor(
                self.struct, OIHBXI, TSEMCG, None, IXQVXO, None, None, AKQXPI
            ),
            IHBXIB: GeckoEnumStructAccessor(
                self.struct, IHBXIB, EMCGET, None, IXQVXO, None, None, AKQXPI
            ),
            HBXIBH: GeckoEnumStructAccessor(
                self.struct, HBXIBH, BXIBHZ, None, XIBHZV, None, None, AKQXPI
            ),
            IBHZVO: GeckoEnumStructAccessor(
                self.struct, IBHZVO, CGETIX, None, XIBHZV, None, None, AKQXPI
            ),
            BHZVOA: GeckoByteStructAccessor(self.struct, BHZVOA, HZVOAC, AKQXPI),
            ZVOACM: GeckoByteStructAccessor(self.struct, ZVOACM, VOACMC, AKQXPI),
            OACMCV: GeckoByteStructAccessor(self.struct, OACMCV, ACMCVD, AKQXPI),
            CMCVDS: GeckoByteStructAccessor(self.struct, CMCVDS, MCVDSS, AKQXPI),
            CVDSSR: GeckoByteStructAccessor(self.struct, CVDSSR, VDSSRU, AKQXPI),
            DSSRUR: GeckoByteStructAccessor(self.struct, DSSRUR, SSRURA, AKQXPI),
            SRURAZ: GeckoByteStructAccessor(self.struct, SRURAZ, RURAZM, AKQXPI),
            URAZMK: GeckoByteStructAccessor(self.struct, URAZMK, RAZMKQ, AKQXPI),
            AZMKQT: GeckoByteStructAccessor(self.struct, AZMKQT, ZMKQTD, AKQXPI),
            NFZCZO: GeckoBoolStructAccessor(self.struct, NFZCZO, JVHFTH, JUTYEK, None),
            FZCZOL: GeckoByteStructAccessor(self.struct, FZCZOL, ZCZOLS, AKQXPI),
            CZOLSI: GeckoByteStructAccessor(self.struct, CZOLSI, ZOLSIP, AKQXPI),
            OLSIPM: GeckoByteStructAccessor(self.struct, OLSIPM, LSIPMD, AKQXPI),
            SIPMDM: GeckoEnumStructAccessor(
                self.struct, SIPMDM, IPMDMP, None, SCTTGC, None, None, AKQXPI
            ),
            CTTGCR: GeckoBoolStructAccessor(
                self.struct, CTTGCR, TTGCRH, QGLRAH, AKQXPI
            ),
            TGCRHY: GeckoBoolStructAccessor(self.struct, TGCRHY, QNRXCH, QGLRAH, None),
        }



#!/usr/bin/python3
"""
    GeckoLogStruct - A class to manage the LogStruct for 'InYT v56'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = 267
ACMCVD = "".join(chr(c) for c in [67, 70, 71, 49, 55])
ACQFFT = "".join(
    chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 105, 103, 76, 105, 98]
)
AFIKJP = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 50])
AHEOCT = 1
AIIDNI = "".join(chr(c) for c in [80, 97, 99, 107, 82, 101, 103, 105, 111, 110])
AJVDQL = 290
AKQXPI = "".join(chr(c) for c in [85, 100, 80, 49])
AKSTSE = 451
AMJMAO = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 83, 116, 117, 99, 107])
AOAWBS = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 50, 72, 83, 116, 117, 99, 107]
)
ASSAKQ = "".join(chr(c) for c in [79, 70, 70])
ATDZXN = "".join(chr(c) for c in [83, 79, 117, 116, 49, 49, 67, 117, 114])
AWBSIR = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 108, 97, 121, 83, 116, 117, 99, 107]
)
AZMKQT = 470
BBEKBD = "".join(chr(c) for c in [67, 70, 71, 50, 56])
BDFSRO = "".join(chr(c) for c in [67, 70, 71, 51, 48])
BDJQRJ = "".join(chr(c) for c in [75, 54, 48, 48, 76, 69])
BEKBDF = 476
BFEGZU = "".join(chr(c) for c in [77, 83, 84, 82, 95, 72, 69, 65, 84, 69, 82])
BHZVOA = 462
BIAMJM = 284
BJEUTO = "".join(chr(c) for c in [80, 50, 76])
BLKXSJ = "".join(chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101])
BMJVHF = 256
BQFYLJ = 354
BQNRXC = "".join(chr(c) for c in [83, 79, 117, 116, 49, 48])
BQSNQL = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 118])
BSIRYX = 351
BSKSOK = "".join(chr(c) for c in [85, 100, 80, 117, 109, 112, 84, 105, 109, 101])
BSSUHB = "".join(
    chr(c)
    for c in [80, 97, 99, 107, 78, 117, 109, 98, 101, 114, 79, 102, 67, 111, 110, 102]
)
BVWVUB = "".join(chr(c) for c in [70, 117, 108, 108])
BXIBHZ = "".join(chr(c) for c in [67, 70, 71, 49, 51])
BXTIAC = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 118])
BXYBQS = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 82, 101, 103, 83, 108, 111, 112, 101]
)
BYGDSB = "".join(chr(c) for c in [75, 52, 48, 48])
CBFEGZ = "".join(chr(c) for c in [76, 49, 50, 48])
CCPQIP = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 68, 117, 114]
)
CGETIX = "".join(chr(c) for c in [67, 70, 71, 55])
CHWDAF = 331
CMCVDS = 465
CPQIPO = 268
CQBMJV = 317
CQFFTT = 295
CRTFMN = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 108])
CTHBSK = 307
CVDSSR = 466
CVYYPI = "".join(chr(c) for c in [68, 101, 97, 108, 101, 114, 79, 112, 116])
CWAONP = "".join(chr(c) for c in [73, 78, 84, 69, 82, 78, 65, 76])
CXQIEF = 4
DDPMXF = 56
DFSROG = 478
DGKEAK = 449
DJQRJJ = "".join(chr(c) for c in [75, 49, 48, 48])
DKHTZB = 473
DPMXFU = 256
DQLAII = "".join(chr(c) for c in [52, 56, 75])
DSBDJQ = "".join(chr(c) for c in [75, 52])
DSSRUR = 467
DUBSSU = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 108])
DZXNQT = "".join(chr(c) for c in [83, 79, 117, 116, 49, 50, 67, 117, 114])
EAKSTS = "".join(chr(c) for c in [67, 70, 71, 51])
ECVYYP = "".join(
    chr(c) for c in [73, 110, 115, 116, 97, 108, 108, 101, 114, 79, 112, 116]
)
EFJTAC = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        68,
        117,
        114,
        80,
        101,
        114,
        68,
        97,
        121,
    ]
)
EFXQGL = "".join(chr(c) for c in [85, 100, 80, 52])
EGZUQE = "".join(chr(c) for c in [83, 76, 86, 95, 72, 69, 65, 84, 69, 82])
EJNIBX = 315
EKBDFS = "".join(chr(c) for c in [67, 70, 71, 50, 57])
EKCWAO = "".join(
    chr(c) for c in [70, 105, 108, 116, 101, 114, 65, 99, 99, 101, 115, 115]
)
EKVKZI = "".join(chr(c) for c in [68, 74, 83, 52])
ELHBQN = 327
EMCGET = "".join(chr(c) for c in [67, 70, 71, 54])
EOCTHB = 308
ETIXQV = "".join(chr(c) for c in [67, 70, 71, 56])
EUTOPH = "".join(chr(c) for c in [80, 51, 76])
EXLSXU = "".join(chr(c) for c in [85, 78, 76, 79, 67, 75])
FCRTFM = 360
FEFJTA = 264
FEGZUQ = 5
FFTTID = 296
FIKJPU = 333
FJBIAM = "".join(chr(c) for c in [82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116])
FJTACC = 266
FMNHTB = 320
FSROGM = "".join(chr(c) for c in [67, 70, 71, 51, 49])
FTHECV = 319
FTSIFJ = "".join(
    chr(c)
    for c in [84, 104, 101, 114, 109, 105, 115, 116, 97, 110, 99, 101, 69, 114, 114]
)
FTTIDU = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 73, 68])
FWRKIN = "".join(chr(c) for c in [70, 76, 67, 69, 114, 114])
FXQGLR = "".join(chr(c) for c in [85, 100, 80, 53])
FYLJUI = "".join(chr(c) for c in [82, 104, 72, 119, 72, 76])
FZDGKE = 448
GDSBDJ = "".join(chr(c) for c in [75, 56])
GETIXQ = 455
GKEAKS = "".join(chr(c) for c in [67, 70, 71, 50])
GLRAHE = "".join(chr(c) for c in [85, 100, 66, 76])
GQPLSP = "".join(
    chr(c) for c in [80, 114, 111, 103, 69, 99, 111, 110, 65, 99, 116, 105, 118, 101]
)
GSELHB = 326
GTYIYW = "".join(chr(c) for c in [83, 79, 117, 116, 50])
GVUNXN = "".join(chr(c) for c in [83, 79, 117, 116, 50, 67, 117, 114])
GYOUSP = "".join(chr(c) for c in [79, 118, 101, 114, 84, 101, 109, 112])
GZUQEX = "".join(chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108])
HBQNRX = 328
HBSKSO = 363
HBVWVU = "".join(chr(c) for c in [82, 101, 115, 116, 114, 105, 99, 116, 101, 100])
HBXIBH = 460
HECVYY = "".join(chr(c) for c in [])
HEOCTH = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48])
HFTHEC = "".join(chr(c) for c in [77, 101, 110, 117])
HIUSOO = "".join(chr(c) for c in [76, 79, 87])
HTBJEU = "".join(chr(c) for c in [80, 49, 76])
HTZBBE = 474
HUGTYI = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
HUOJRJ = 306
HWDAFI = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116])
HXEKVK = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
HZVOAC = "".join(chr(c) for c in [67, 70, 71, 49, 53])
IACQFF = 294
IAMJMA = "".join(chr(c) for c in [80, 50, 72, 83, 116, 117, 99, 107])
IBHZVO = "".join(chr(c) for c in [67, 70, 71, 49, 52])
IBXTIA = 291
IBXYBQ = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
ICXQIE = 0
IDNIBX = "".join(chr(c) for c in [67, 69])
IDUBSS = 299
IEFXQG = "".join(chr(c) for c in [85, 100, 80, 51])
IFJBIA = 283
IGYOUS = 355
IHBXIB = "".join(chr(c) for c in [67, 70, 71, 49, 50])
IIDNIB = "".join(chr(c) for c in [85, 76])
IJUGSE = "".join(chr(c) for c in [83, 79, 117, 116, 54])
IKFWRK = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 88, 84, 114, 105, 101, 115]
)
IKJPUN = "".join(chr(c) for c in [83, 79, 117, 116, 54, 67, 117, 114])
ILXWAJ = "".join(chr(c) for c in [105, 110, 84, 111, 117, 99, 104])
INEJNI = 314
IPIVLA = "".join(chr(c) for c in [81, 117, 105, 101, 116, 83, 116, 97, 116, 101])
IPOUYN = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 78, 98, 79, 102, 80, 104, 97, 115, 101, 115]
)
IRYXBQ = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        70,
        117,
        115,
        101,
        69,
        114,
        114,
    ]
)
IUXFEF = "".join(chr(c) for c in [65, 67, 84, 73, 86, 69])
IVDNQG = 334
IVLASS = "".join(chr(c) for c in [78, 79, 84, 95, 83, 69, 84])
IXQVXO = "".join(chr(c) for c in [67, 70, 71, 57])
IYWSKW = 322
JBIAMJ = "".join(chr(c) for c in [80, 49, 72, 83, 116, 117, 99, 107])
JEUTOP = "".join(chr(c) for c in [80, 51, 72])
JHIUSO = "".join(chr(c) for c in [72, 73, 71, 72])
JIGYOU = "".join(chr(c) for c in [83, 119, 109, 65, 100, 99])
JJJVYF = "".join(chr(c) for c in [73, 78, 86, 65, 76, 73, 68])
JMAOAW = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 49, 72, 83, 116, 117, 99, 107]
)
JMCBFE = "".join(chr(c) for c in [79, 51])
JNIBXY = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 78, 111, 70, 108, 111, 69, 114, 114]
)
JPUNRJ = "".join(chr(c) for c in [83, 79, 117, 116, 55, 67, 117, 114])
JQRJJJ = "".join(chr(c) for c in [75, 56, 48, 48])
JRJHIU = "".join(chr(c) for c in [80, 49])
JTACCP = "".join(
    chr(c) for c in [69, 99, 111, 110, 111, 109, 121, 65, 99, 99, 101, 115, 115]
)
JUGSEL = 325
JUIKFW = "".join(
    chr(c) for c in [82, 104, 72, 114, 75, 105, 110, 78, 111, 70, 108, 111]
)
JUTYEK = "".join(
    chr(c) for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 83, 101, 101, 100]
)
JVDQLA = "".join(chr(c) for c in [49, 54, 75])
JVHFTH = 274
JVYFCR = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 73, 68])
JWMNZM = "".join(chr(c) for c in [77, 69, 68])
JYKLGQ = 279
JYMOUN = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 66, 121, 85, 68]
)
JZTATD = 343
KBDFSR = 477
KCWAON = 262
KEAKST = 450
KHTZBB = "".join(chr(c) for c in [67, 70, 71, 50, 54])
KINEJN = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
KJPUNR = 340
KLGQPL = "".join(chr(c) for c in [67, 104, 101, 99, 107, 70, 108, 111])
KMLOIJ = "".join(chr(c) for c in [83, 79, 117, 116, 53, 67, 117, 114])
KPHUOJ = 305
KQTDKH = "".join(chr(c) for c in [67, 70, 71, 50, 52])
KQXPIC = 259
KSOKPH = "".join(chr(c) for c in [85, 100, 81, 117, 105, 101, 116, 84, 105, 109, 101])
KSTSEM = "".join(chr(c) for c in [67, 70, 71, 52])
KVKZIL = "".join(chr(c) for c in [105, 110, 67, 108, 101, 97, 114])
KWIVDN = 324
KXSJWM = "".join(chr(c) for c in [83, 119, 109, 82, 105, 115, 107])
KZILXW = "".join(chr(c) for c in [75, 54, 48, 48])
LASSAK = "".join(chr(c) for c in [83, 79, 65, 75])
LGQPLS = 280
LHBQNR = "".join(chr(c) for c in [83, 79, 117, 116, 57])
LIUXFE = "".join(chr(c) for c in [78, 69, 87])
LJUIKF = "".join(chr(c) for c in [82, 104, 82, 101, 103, 83, 108, 111, 112, 101])
LKXSJW = "".join(chr(c) for c in [83, 119, 109, 65, 99, 116, 105, 118, 101])
LNMHXE = 289
LOIJUG = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114, 67, 117, 114])
LRAHEO = "".join(chr(c) for c in [79, 78])
LSPFTS = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 79, 118, 101, 114, 84, 101, 109, 112]
)
LSXUJU = "".join(chr(c) for c in [70, 85, 76, 76])
LXWAJV = "".join(chr(c) for c in [105, 110, 89, 84])
MAOAWB = 350
MCBFEG = 3
MCGETI = 454
MCVDSS = "".join(chr(c) for c in [67, 70, 71, 49, 56])
MFZDGK = "".join(chr(c) for c in [67, 70, 71, 48])
MHXEKV = "".join(chr(c) for c in [105, 110, 88, 69])
MJIGYO = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 65, 99, 116, 105, 118, 101]
)
MJMAOA = "".join(chr(c) for c in [82, 101, 108, 97, 121, 83, 116, 117, 99, 107])
MJVHFT = "".join(
    chr(c) for c in [83, 116, 105, 99, 107, 68, 101, 116, 101, 99, 116, 101, 100]
)
MKQTDK = 471
MLOIJU = 339
MNHTBJ = "".join(chr(c) for c in [78, 65])
MOUNBL = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        69,
        114,
        114,
    ]
)
NBLKXS = 282
NEJNIB = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 78, 111, 70, 108, 111, 69, 114, 114]
)
NHTBJE = "".join(chr(c) for c in [80, 49, 72])
NIBXTI = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 73, 68])
NIBXYB = "".join(chr(c) for c in [83, 108, 97, 118, 101, 72, 76, 69, 114, 114])
NKMLOI = 338
NMHXEK = "".join(chr(c) for c in [85, 110, 107, 110, 111, 119, 110])
NPYYLI = 263
NQGVUN = "".join(chr(c) for c in [83, 79, 117, 116, 49, 67, 117, 114])
NQJYMO = 273
NQLNMH = 288
NQTMFZ = 347
NRJZTA = 342
NRXCHW = "".join(chr(c) for c in [83, 79, 117, 116, 49, 49])
NXNKML = 337
NZMJIG = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 80, 117, 114, 103, 101]
)
OACMCV = 464
OAWBSI = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 72, 116, 114, 83, 116, 117, 99, 107]
)
OCTHBS = "".join(chr(c) for c in [85, 100, 76, 105])
OGMDDP = "".join(chr(c) for c in [76, 73])
OIHBXI = 459
OIJUGS = 349
OJRJHI = 362
OKPHUO = "".join(chr(c) for c in [85, 100, 76, 105, 103, 104, 116, 84, 105, 109, 101])
ONPYYL = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
OOQNRS = "".join(chr(c) for c in [80, 52])
OPHUGT = "".join(chr(c) for c in [66, 76, 79])
OQNRSJ = "".join(chr(c) for c in [80, 53])
OUNBLK = "".join(chr(c) for c in [67, 80, 79, 84])
OUSPBW = 275
OUYNQJ = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        66,
        114,
        101,
        97,
        107,
        101,
        114,
        73,
        110,
        100,
        101,
        120,
    ]
)
PBWJYK = "".join(chr(c) for c in [72, 101, 97, 116, 105, 110, 103])
PFTSIF = "".join(
    chr(c) for c in [84, 104, 101, 114, 109, 70, 117, 115, 101, 69, 114, 114]
)
PHUGTY = "".join(chr(c) for c in [70, 97, 110])
PHUOJR = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48, 84, 105, 109, 101])
PIVLAS = 257
PLSPFT = "".join(chr(c) for c in [69, 99, 111, 110, 65, 99, 116, 105, 118, 101])
PMXFUB = 479
POUYNQ = 271
PQIPOU = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        67,
        111,
        110,
        102,
        105,
        103,
        73,
        110,
        100,
        101,
        120,
    ]
)
PUNRJZ = 341
PYYLIU = "".join(chr(c) for c in [73, 68, 76, 69])
QBMJVH = "".join(chr(c) for c in [72, 111, 117, 114, 115])
QEXLSX = 310
QFFTTI = "".join(
    chr(c) for c in [80, 97, 99, 107, 83, 116, 97, 116, 117, 115, 76, 105, 98]
)
QFYLJU = "".join(
    chr(c) for c in [82, 104, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
QGVUNX = 335
QIEFXQ = 2
QIPOUY = 270
QJYMOU = "".join(chr(c) for c in [80, 117, 114, 103, 101])
QLAIID = "".join(chr(c) for c in [54, 52, 75])
QLNMHX = "".join(chr(c) for c in [80, 97, 99, 107, 84, 121, 112, 101])
QNRSJM = 260
QNRXCH = 329
QPLSPF = 281
QRJJJV = "".join(chr(c) for c in [75, 54, 48, 48, 72, 69])
QSNQLN = 287
QTDKHT = 472
QTMFZD = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 50, 67, 117, 114])
QVXOIH = "".join(chr(c) for c in [67, 70, 71, 49, 48])
QXPICX = "".join(chr(c) for c in [76, 79])
RAZMKQ = "".join(chr(c) for c in [67, 70, 71, 50, 50])
RJHIUS = 261
RJJJVY = "".join(chr(c) for c in [75, 51, 48, 48])
RJZTAT = "".join(chr(c) for c in [83, 79, 117, 116, 57, 67, 117, 114])
RKINEJ = 311
RSJMCB = "".join(chr(c) for c in [66, 76])
RTFMNH = 361
RURAZM = "".join(chr(c) for c in [67, 70, 71, 50, 49])
RXCHWD = 330
RYXBQF = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        105,
        115,
        116,
        97,
        110,
        99,
        101,
        69,
        114,
        114,
    ]
)
SAKQXP = "".join(chr(c) for c in [65, 76, 76])
SBDJQR = "".join(chr(c) for c in [75, 53])
SELHBQ = "".join(chr(c) for c in [83, 79, 117, 116, 56])
SEMCGE = 453
SIFJBI = "".join(chr(c) for c in [75, 105, 110, 80, 117, 109, 112, 79, 102, 102])
SIRYXB = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116]
)
SJMCBF = "".join(chr(c) for c in [67, 80])
SJWMNZ = "".join(chr(c) for c in [78, 79])
SKSOKP = 303
SKWIVD = "".join(chr(c) for c in [83, 79, 117, 116, 53])
SNQLNM = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 108])
SOKPHU = 304
SOOQNR = "".join(chr(c) for c in [80, 51])
SPBWJY = 277
SPFTSI = 352
SROGMD = 479
SRURAZ = 468
SSRURA = "".join(chr(c) for c in [67, 70, 71, 50, 48])
SSUHBV = 301
STSEMC = 452
SUHBVW = "".join(chr(c) for c in [80, 97, 99, 107, 76, 111, 103, 84, 114, 105, 103])
TACCPQ = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 65, 99, 116, 105, 111, 110]
)
TATDZX = 344
TBJEUT = "".join(chr(c) for c in [80, 50, 72])
TDKHTZ = "".join(chr(c) for c in [67, 70, 71, 50, 53])
TDZXNQ = 345
TFMNHT = "".join(chr(c) for c in [83, 79, 117, 116, 49])
THBSKS = "".join(chr(c) for c in [85, 100, 87, 97, 116, 101, 114, 102, 97, 108, 108])
THECVY = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
TIACQF = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 108])
TIDUBS = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 118])
TIXQVX = 456
TMFZDG = 348
TOPHUG = "".join(chr(c) for c in [80, 52, 76])
TSEMCG = "".join(chr(c) for c in [67, 70, 71, 53])
TSIFJB = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 50]
)
TTIDUB = 297
TYEKCW = "".join(
    chr(c) for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 75, 101, 121]
)
TYIYWS = 321
TZBBEK = "".join(chr(c) for c in [67, 70, 71, 50, 55])
UBSSUH = 300
UBYGDS = "".join(chr(c) for c in [75, 50, 48, 48])
UGSELH = "".join(chr(c) for c in [83, 79, 117, 116, 55])
UHBVWV = 316
UIKFWR = 309
UJUTYE = 364
UNBLKX = "".join(
    chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101, 83, 117, 115, 112]
)
UNRJZT = "".join(chr(c) for c in [83, 79, 117, 116, 56, 67, 117, 114])
UNXNKM = "".join(chr(c) for c in [83, 79, 117, 116, 51, 67, 117, 114])
UOJRJH = "".join(
    chr(c)
    for c in [85, 100, 87, 97, 116, 101, 114, 70, 97, 108, 108, 84, 105, 109, 101]
)
UQEXLS = "".join(chr(c) for c in [76, 111, 99, 107, 77, 111, 100, 101])
URAZMK = 469
USOOQN = "".join(chr(c) for c in [80, 50])
USPBWJ = "".join(
    chr(c) for c in [68, 105, 115, 112, 108, 97, 121, 101, 100, 84, 101, 109, 112, 71]
)
UTOPHU = "".join(chr(c) for c in [80, 52, 72])
UTYEKC = 365
UYNQJY = 272
VDNQGV = "".join(chr(c) for c in [72, 84, 82])
VDQLAI = "".join(chr(c) for c in [51, 50, 75])
VDSSRU = "".join(chr(c) for c in [67, 70, 71, 49, 57])
VHFTHE = 6
VKZILX = "".join(chr(c) for c in [105, 110, 88, 77])
VLASSA = "".join(chr(c) for c in [68, 82, 65, 73, 78])
VOACMC = "".join(chr(c) for c in [67, 70, 71, 49, 54])
VUBYGD = 357
VUNXNK = 336
VXOIHB = 458
VYFCRT = 358
VYYPIP = "".join(
    chr(c) for c in [65, 99, 99, 101, 115, 115, 111, 114, 121, 79, 112, 116]
)
WAJVDQ = "".join(chr(c) for c in [80, 97, 99, 107, 77, 101, 109, 82, 97, 110, 103, 101])
WAONPY = "".join(chr(c) for c in [82, 69, 77, 79, 84, 69])
WBSIRY = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 80, 117, 109, 112, 79, 102, 102]
)
WDAFIK = 332
WIVDNQ = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114])
WJYKLG = "".join(
    chr(c) for c in [84, 101, 109, 112, 78, 111, 116, 86, 97, 108, 105, 100]
)
WMNZMJ = "".join(chr(c) for c in [69, 88, 84, 82, 69, 77, 69])
WRKINE = "".join(chr(c) for c in [105, 110, 84, 67, 105, 112, 68, 101, 108, 97, 121])
WSKWIV = 323
WVUBYG = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 84, 121, 112, 101])
XBQFYL = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 77, 105, 115, 115, 105, 110, 103, 69, 114, 114]
)
XCHWDA = "".join(chr(c) for c in [83, 79, 117, 116, 49, 50])
XEKVKZ = "".join(chr(c) for c in [77, 73, 65])
XFEFJT = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 70, 105, 108, 116, 68, 117, 114]
)
XIBHZV = 461
XLSXUJ = "".join(chr(c) for c in [80, 65, 82, 84, 73, 65, 76])
XNKMLO = "".join(chr(c) for c in [83, 79, 117, 116, 52, 67, 117, 114])
XNQTMF = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 67, 117, 114])
XOIHBX = "".join(chr(c) for c in [67, 70, 71, 49, 49])
XPICXQ = "".join(chr(c) for c in [72, 73])
XQGLRA = 258
XQIEFX = "".join(chr(c) for c in [85, 100, 80, 50])
XQVXOI = 457
XSJWMN = 313
XTIACQ = 293
XUJUTY = "".join(
    chr(c)
    for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 83, 116, 97, 116, 117, 115]
)
XYBQSN = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 73, 68])
YBQSNQ = 285
YEKCWA = 367
YFCRTF = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 118])
YGDSBD = "".join(chr(c) for c in [75, 56, 53])
YIYWSK = "".join(chr(c) for c in [83, 79, 117, 116, 51])
YKLGQP = "".join(
    chr(c)
    for c in [69, 120, 116, 80, 114, 111, 98, 101, 68, 101, 116, 101, 99, 116, 101, 100]
)
YLIUXF = "".join(chr(c) for c in [83, 84, 65, 82, 84])
YLJUIK = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
YMOUNB = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        79,
        84,
    ]
)
YNQJYM = "".join(chr(c) for c in [67, 108, 101, 97, 110])
YOUSPB = "".join(
    chr(c) for c in [82, 101, 97, 108, 83, 101, 116, 80, 111, 105, 110, 116, 71]
)
YPIPIV = "".join(chr(c) for c in [83, 116, 105, 99, 107, 66, 97, 110, 107])
YWSKWI = "".join(chr(c) for c in [83, 79, 117, 116, 52])
YXBQFY = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        65,
        109,
        98,
        105,
        97,
        110,
        116,
        79,
        72,
        76,
        101,
        118,
        101,
        108,
        50,
    ]
)
YYLIUX = "".join(chr(c) for c in [83, 84, 79, 80])
YYPIPI = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 83, 101, 108, 101, 99, 116]
)
ZBBEKB = 475
ZCQBMJ = "".join(chr(c) for c in [82, 104, 87, 97, 116, 101, 114, 84, 101, 109, 112])
ZDGKEA = "".join(chr(c) for c in [67, 70, 71, 49])
ZILXWA = "".join(chr(c) for c in [105, 110, 84, 101, 114, 102, 97, 99, 101])
ZMJIGY = 353
ZMKQTD = "".join(chr(c) for c in [67, 70, 71, 50, 51])
ZTATDZ = "".join(chr(c) for c in [83, 79, 117, 116, 49, 48, 67, 117, 114])
ZUQEXL = 7
ZVOACM = 463
ZXNQTM = 346
AONPYY = [CWAONP, WAONPY]
BWJYKL = [HECVYY, PBWJYK, PBWJYK, PBWJYK]
DAFIKJ = [
    MNHTBJ,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    SJMCBF,
]
DNIBXT = [IIDNIB, IDNIBX]
DNQGVU = [
    MNHTBJ,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    VDNQGV,
]
GMDDPM = [
    JRJHIU,
    USOOQN,
    SOOQNR,
    OOQNRS,
    OQNRSJ,
    RSJMCB,
    SJMCBF,
    JMCBFE,
    CBFEGZ,
    BFEGZU,
    EGZUQE,
    GZUQEX,
    UQEXLS,
    XUJUTY,
    JUTYEK,
    TYEKCW,
    OGMDDP,
]
IUSOOQ = [ASSAKQ, JHIUSO, HIUSOO]
JJVYFC = [
    UBYGDS,
    BYGDSB,
    YGDSBD,
    GDSBDJ,
    DSBDJQ,
    SBDJQR,
    BDJQRJ,
    DJQRJJ,
    JQRJJJ,
    HECVYY,
    HECVYY,
    HECVYY,
    QRJJJV,
    RJJJVY,
    JJJVYF,
]
KFWRKI = [HECVYY, IKFWRK, IKFWRK, IKFWRK]
LAIIDN = [JVDQLA, VDQLAI, DQLAII, QLAIID]
MDDPMX = [
    AKQXPI,
    XQIEFX,
    IEFXQG,
    EFXQGL,
    FXQGLR,
    GLRAHE,
    HEOCTH,
    OCTHBS,
    THBSKS,
    BSKSOK,
    KSOKPH,
    OKPHUO,
    PHUOJR,
    UOJRJH,
]
MNZMJI = [SJWMNZ, QXPICX, JWMNZM, XPICXQ, WMNZMJ]
NRSJMC = [ASSAKQ, JHIUSO]
PICXQI = [ASSAKQ, QXPICX, XPICXQ]
PIPIVL = [
    THECVY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    HECVYY,
    YPIPIV,
]
QGLRAH = [ASSAKQ, XPICXQ]
RAHEOC = [ASSAKQ, LRAHEO]
ROGMDD = []
SSAKQX = [IVLASS, VLASSA, LASSAK, ASSAKQ]
SXUJUT = [EXLSXU, XLSXUJ, LSXUJU]
UGTYIY = [
    MNHTBJ,
    NHTBJE,
    HTBJEU,
    TBJEUT,
    BJEUTO,
    JEUTOP,
    EUTOPH,
    UTOPHU,
    TOPHUG,
    OQNRSJ,
    OPHUGT,
    SJMCBF,
    JMCBFE,
    CBFEGZ,
    HECVYY,
    HECVYY,
    PHUGTY,
    HECVYY,
    HECVYY,
    HUGTYI,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    GZUQEX,
]
UXFEFJ = [PYYLIU, YYLIUX, YLIUXF, LIUXFE, IUXFEF]
VWVUBY = [HBVWVU, BVWVUB]
XWAJVD = [
    NMHXEK,
    MHXEKV,
    HXEKVK,
    XEKVKZ,
    EKVKZI,
    KVKZIL,
    VKZILX,
    KZILXW,
    ZILXWA,
    ILXWAJ,
    LXWAJV,
]


class GeckoLogStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return DDPMXF

    @property
    def begin(self):
        return DPMXFU

    @property
    def end(self):
        return PMXFUB

    @property
    def all_device_keys(self):
        return GMDDPM

    @property
    def user_demand_keys(self):
        return MDDPMX

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoTempStructAccessor(self.struct, ZCQBMJ, CQBMJV, None),
            QBMJVH: GeckoByteStructAccessor(self.struct, QBMJVH, BMJVHF, None),
            MJVHFT: GeckoBoolStructAccessor(self.struct, MJVHFT, JVHFTH, VHFTHE, None),
            HFTHEC: GeckoEnumStructAccessor(
                self.struct, HFTHEC, FTHECV, None, PIPIVL, None, None, None
            ),
            IPIVLA: GeckoEnumStructAccessor(
                self.struct, IPIVLA, PIVLAS, None, SSAKQX, None, None, SAKQXP
            ),
            AKQXPI: GeckoEnumStructAccessor(
                self.struct, AKQXPI, KQXPIC, ICXQIE, PICXQI, None, CXQIEF, SAKQXP
            ),
            XQIEFX: GeckoEnumStructAccessor(
                self.struct, XQIEFX, KQXPIC, QIEFXQ, PICXQI, None, CXQIEF, SAKQXP
            ),
            IEFXQG: GeckoEnumStructAccessor(
                self.struct, IEFXQG, KQXPIC, CXQIEF, PICXQI, None, CXQIEF, SAKQXP
            ),
            EFXQGL: GeckoEnumStructAccessor(
                self.struct, EFXQGL, KQXPIC, VHFTHE, PICXQI, None, CXQIEF, SAKQXP
            ),
            FXQGLR: GeckoEnumStructAccessor(
                self.struct, FXQGLR, XQGLRA, ICXQIE, QGLRAH, None, QIEFXQ, SAKQXP
            ),
            GLRAHE: GeckoEnumStructAccessor(
                self.struct, GLRAHE, XQGLRA, AHEOCT, RAHEOC, None, QIEFXQ, SAKQXP
            ),
            HEOCTH: GeckoEnumStructAccessor(
                self.struct, HEOCTH, EOCTHB, None, RAHEOC, None, None, SAKQXP
            ),
            OCTHBS: GeckoEnumStructAccessor(
                self.struct, OCTHBS, CTHBSK, None, QGLRAH, None, None, SAKQXP
            ),
            THBSKS: GeckoEnumStructAccessor(
                self.struct, THBSKS, HBSKSO, None, RAHEOC, None, None, SAKQXP
            ),
            BSKSOK: GeckoByteStructAccessor(self.struct, BSKSOK, SKSOKP, SAKQXP),
            KSOKPH: GeckoByteStructAccessor(self.struct, KSOKPH, SOKPHU, SAKQXP),
            OKPHUO: GeckoByteStructAccessor(self.struct, OKPHUO, KPHUOJ, SAKQXP),
            PHUOJR: GeckoByteStructAccessor(self.struct, PHUOJR, HUOJRJ, SAKQXP),
            UOJRJH: GeckoByteStructAccessor(self.struct, UOJRJH, OJRJHI, SAKQXP),
            JRJHIU: GeckoEnumStructAccessor(
                self.struct, JRJHIU, RJHIUS, ICXQIE, IUSOOQ, None, CXQIEF, None
            ),
            USOOQN: GeckoEnumStructAccessor(
                self.struct, USOOQN, RJHIUS, QIEFXQ, IUSOOQ, None, CXQIEF, None
            ),
            SOOQNR: GeckoEnumStructAccessor(
                self.struct, SOOQNR, RJHIUS, CXQIEF, IUSOOQ, None, CXQIEF, None
            ),
            OOQNRS: GeckoEnumStructAccessor(
                self.struct, OOQNRS, RJHIUS, VHFTHE, IUSOOQ, None, CXQIEF, None
            ),
            OQNRSJ: GeckoEnumStructAccessor(
                self.struct, OQNRSJ, QNRSJM, ICXQIE, NRSJMC, None, QIEFXQ, None
            ),
            RSJMCB: GeckoEnumStructAccessor(
                self.struct, RSJMCB, QNRSJM, AHEOCT, RAHEOC, None, QIEFXQ, None
            ),
            SJMCBF: GeckoEnumStructAccessor(
                self.struct, SJMCBF, QNRSJM, QIEFXQ, RAHEOC, None, QIEFXQ, None
            ),
            JMCBFE: GeckoEnumStructAccessor(
                self.struct, JMCBFE, QNRSJM, MCBFEG, RAHEOC, None, QIEFXQ, None
            ),
            CBFEGZ: GeckoEnumStructAccessor(
                self.struct, CBFEGZ, QNRSJM, CXQIEF, RAHEOC, None, QIEFXQ, None
            ),
            BFEGZU: GeckoEnumStructAccessor(
                self.struct, BFEGZU, QNRSJM, FEGZUQ, RAHEOC, None, QIEFXQ, None
            ),
            EGZUQE: GeckoEnumStructAccessor(
                self.struct, EGZUQE, QNRSJM, VHFTHE, RAHEOC, None, QIEFXQ, None
            ),
            GZUQEX: GeckoEnumStructAccessor(
                self.struct, GZUQEX, QNRSJM, ZUQEXL, RAHEOC, None, QIEFXQ, None
            ),
            UQEXLS: GeckoEnumStructAccessor(
                self.struct, UQEXLS, QEXLSX, None, SXUJUT, None, None, SAKQXP
            ),
            XUJUTY: GeckoEnumStructAccessor(
                self.struct, XUJUTY, UJUTYE, None, SXUJUT, None, None, None
            ),
            JUTYEK: GeckoWordStructAccessor(self.struct, JUTYEK, UTYEKC, None),
            TYEKCW: GeckoWordStructAccessor(self.struct, TYEKCW, YEKCWA, SAKQXP),
            EKCWAO: GeckoEnumStructAccessor(
                self.struct, EKCWAO, KCWAON, ICXQIE, AONPYY, None, QIEFXQ, SAKQXP
            ),
            ONPYYL: GeckoEnumStructAccessor(
                self.struct, ONPYYL, NPYYLI, None, UXFEFJ, None, None, SAKQXP
            ),
            XFEFJT: GeckoTimeStructAccessor(self.struct, XFEFJT, FEFJTA, SAKQXP),
            EFJTAC: GeckoByteStructAccessor(self.struct, EFJTAC, FJTACC, SAKQXP),
            JTACCP: GeckoEnumStructAccessor(
                self.struct, JTACCP, KCWAON, QIEFXQ, AONPYY, None, QIEFXQ, SAKQXP
            ),
            TACCPQ: GeckoEnumStructAccessor(
                self.struct, TACCPQ, ACCPQI, None, UXFEFJ, None, None, SAKQXP
            ),
            CCPQIP: GeckoTimeStructAccessor(self.struct, CCPQIP, CPQIPO, SAKQXP),
            PQIPOU: GeckoByteStructAccessor(self.struct, PQIPOU, QIPOUY, SAKQXP),
            IPOUYN: GeckoByteStructAccessor(self.struct, IPOUYN, POUYNQ, SAKQXP),
            OUYNQJ: GeckoByteStructAccessor(self.struct, OUYNQJ, UYNQJY, SAKQXP),
            YNQJYM: GeckoBoolStructAccessor(self.struct, YNQJYM, NQJYMO, ICXQIE, None),
            QJYMOU: GeckoBoolStructAccessor(self.struct, QJYMOU, NQJYMO, QIEFXQ, None),
            JYMOUN: GeckoBoolStructAccessor(self.struct, JYMOUN, NQJYMO, MCBFEG, None),
            YMOUNB: GeckoBoolStructAccessor(self.struct, YMOUNB, NQJYMO, CXQIEF, None),
            MOUNBL: GeckoBoolStructAccessor(self.struct, MOUNBL, NQJYMO, FEGZUQ, None),
            OUNBLK: GeckoBoolStructAccessor(self.struct, OUNBLK, JVHFTH, QIEFXQ, None),
            UNBLKX: GeckoBoolStructAccessor(self.struct, UNBLKX, NBLKXS, MCBFEG, None),
            BLKXSJ: GeckoBoolStructAccessor(self.struct, BLKXSJ, NBLKXS, FEGZUQ, None),
            LKXSJW: GeckoBoolStructAccessor(self.struct, LKXSJW, NBLKXS, VHFTHE, None),
            KXSJWM: GeckoEnumStructAccessor(
                self.struct, KXSJWM, XSJWMN, None, MNZMJI, None, None, None
            ),
            NZMJIG: GeckoBoolStructAccessor(self.struct, NZMJIG, ZMJIGY, FEGZUQ, None),
            MJIGYO: GeckoBoolStructAccessor(self.struct, MJIGYO, ZMJIGY, VHFTHE, None),
            JIGYOU: GeckoWordStructAccessor(self.struct, JIGYOU, IGYOUS, None),
            GYOUSP: GeckoBoolStructAccessor(self.struct, GYOUSP, JVHFTH, AHEOCT, None),
            YOUSPB: GeckoTempStructAccessor(self.struct, YOUSPB, OUSPBW, None),
            USPBWJ: GeckoTempStructAccessor(self.struct, USPBWJ, SPBWJY, None),
            PBWJYK: GeckoEnumStructAccessor(
                self.struct, PBWJYK, QNRSJM, FEGZUQ, BWJYKL, None, CXQIEF, None
            ),
            WJYKLG: GeckoBoolStructAccessor(self.struct, WJYKLG, JYKLGQ, QIEFXQ, None),
            YKLGQP: GeckoBoolStructAccessor(self.struct, YKLGQP, JYKLGQ, VHFTHE, None),
            KLGQPL: GeckoBoolStructAccessor(self.struct, KLGQPL, LGQPLS, QIEFXQ, None),
            GQPLSP: GeckoBoolStructAccessor(self.struct, GQPLSP, QPLSPF, AHEOCT, None),
            PLSPFT: GeckoBoolStructAccessor(
                self.struct, PLSPFT, QPLSPF, QIEFXQ, SAKQXP
            ),
            LSPFTS: GeckoBoolStructAccessor(self.struct, LSPFTS, SPFTSI, AHEOCT, None),
            PFTSIF: GeckoBoolStructAccessor(self.struct, PFTSIF, JVHFTH, MCBFEG, None),
            FTSIFJ: GeckoBoolStructAccessor(self.struct, FTSIFJ, NBLKXS, ICXQIE, None),
            TSIFJB: GeckoBoolStructAccessor(self.struct, TSIFJB, NBLKXS, AHEOCT, None),
            SIFJBI: GeckoBoolStructAccessor(self.struct, SIFJBI, IFJBIA, QIEFXQ, None),
            FJBIAM: GeckoBoolStructAccessor(self.struct, FJBIAM, IFJBIA, MCBFEG, None),
            JBIAMJ: GeckoBoolStructAccessor(self.struct, JBIAMJ, BIAMJM, MCBFEG, None),
            IAMJMA: GeckoBoolStructAccessor(self.struct, IAMJMA, BIAMJM, CXQIEF, None),
            AMJMAO: GeckoBoolStructAccessor(self.struct, AMJMAO, BIAMJM, FEGZUQ, None),
            MJMAOA: GeckoBoolStructAccessor(self.struct, MJMAOA, BIAMJM, VHFTHE, None),
            JMAOAW: GeckoBoolStructAccessor(self.struct, JMAOAW, MAOAWB, MCBFEG, None),
            AOAWBS: GeckoBoolStructAccessor(self.struct, AOAWBS, MAOAWB, CXQIEF, None),
            OAWBSI: GeckoBoolStructAccessor(self.struct, OAWBSI, MAOAWB, FEGZUQ, None),
            AWBSIR: GeckoBoolStructAccessor(self.struct, AWBSIR, MAOAWB, VHFTHE, None),
            WBSIRY: GeckoBoolStructAccessor(self.struct, WBSIRY, BSIRYX, QIEFXQ, None),
            SIRYXB: GeckoBoolStructAccessor(self.struct, SIRYXB, BSIRYX, MCBFEG, None),
            IRYXBQ: GeckoBoolStructAccessor(self.struct, IRYXBQ, SPFTSI, MCBFEG, None),
            RYXBQF: GeckoBoolStructAccessor(self.struct, RYXBQF, ZMJIGY, ICXQIE, None),
            YXBQFY: GeckoBoolStructAccessor(self.struct, YXBQFY, ZMJIGY, AHEOCT, None),
            XBQFYL: GeckoBoolStructAccessor(self.struct, XBQFYL, BQFYLJ, ICXQIE, None),
            QFYLJU: GeckoBoolStructAccessor(self.struct, QFYLJU, LGQPLS, ICXQIE, None),
            FYLJUI: GeckoBoolStructAccessor(self.struct, FYLJUI, IFJBIA, ICXQIE, None),
            YLJUIK: GeckoBoolStructAccessor(self.struct, YLJUIK, IFJBIA, AHEOCT, None),
            LJUIKF: GeckoBoolStructAccessor(self.struct, LJUIKF, IFJBIA, CXQIEF, None),
            JUIKFW: GeckoBoolStructAccessor(self.struct, JUIKFW, UIKFWR, ICXQIE, None),
            IKFWRK: GeckoEnumStructAccessor(
                self.struct, IKFWRK, UIKFWR, AHEOCT, KFWRKI, None, CXQIEF, None
            ),
            FWRKIN: GeckoBoolStructAccessor(self.struct, FWRKIN, UIKFWR, MCBFEG, None),
            WRKINE: GeckoWordStructAccessor(self.struct, WRKINE, RKINEJ, None),
            KINEJN: GeckoBoolStructAccessor(self.struct, KINEJN, INEJNI, ICXQIE, None),
            NEJNIB: GeckoBoolStructAccessor(self.struct, NEJNIB, EJNIBX, ICXQIE, None),
            JNIBXY: GeckoBoolStructAccessor(self.struct, JNIBXY, EJNIBX, AHEOCT, None),
            NIBXYB: GeckoBoolStructAccessor(self.struct, NIBXYB, BSIRYX, ICXQIE, None),
            IBXYBQ: GeckoBoolStructAccessor(self.struct, IBXYBQ, BSIRYX, AHEOCT, None),
            BXYBQS: GeckoBoolStructAccessor(self.struct, BXYBQS, BSIRYX, CXQIEF, None),
            XYBQSN: GeckoWordStructAccessor(self.struct, XYBQSN, YBQSNQ, None),
            BQSNQL: GeckoByteStructAccessor(self.struct, BQSNQL, QSNQLN, None),
            SNQLNM: GeckoByteStructAccessor(self.struct, SNQLNM, NQLNMH, None),
            QLNMHX: GeckoEnumStructAccessor(
                self.struct, QLNMHX, LNMHXE, None, XWAJVD, None, None, None
            ),
            WAJVDQ: GeckoEnumStructAccessor(
                self.struct, WAJVDQ, AJVDQL, ICXQIE, LAIIDN, None, CXQIEF, None
            ),
            AIIDNI: GeckoEnumStructAccessor(
                self.struct, AIIDNI, AJVDQL, QIEFXQ, DNIBXT, None, QIEFXQ, None
            ),
            NIBXTI: GeckoWordStructAccessor(self.struct, NIBXTI, IBXTIA, None),
            BXTIAC: GeckoByteStructAccessor(self.struct, BXTIAC, XTIACQ, None),
            TIACQF: GeckoByteStructAccessor(self.struct, TIACQF, IACQFF, None),
            ACQFFT: GeckoByteStructAccessor(self.struct, ACQFFT, CQFFTT, None),
            QFFTTI: GeckoByteStructAccessor(self.struct, QFFTTI, FFTTID, None),
            FTTIDU: GeckoWordStructAccessor(self.struct, FTTIDU, TTIDUB, None),
            TIDUBS: GeckoByteStructAccessor(self.struct, TIDUBS, IDUBSS, None),
            DUBSSU: GeckoByteStructAccessor(self.struct, DUBSSU, UBSSUH, None),
            BSSUHB: GeckoWordStructAccessor(self.struct, BSSUHB, SSUHBV, None),
            SUHBVW: GeckoEnumStructAccessor(
                self.struct, SUHBVW, UHBVWV, None, VWVUBY, None, QIEFXQ, SAKQXP
            ),
            WVUBYG: GeckoEnumStructAccessor(
                self.struct, WVUBYG, VUBYGD, None, JJVYFC, None, None, None
            ),
            JVYFCR: GeckoWordStructAccessor(self.struct, JVYFCR, VYFCRT, None),
            YFCRTF: GeckoByteStructAccessor(self.struct, YFCRTF, FCRTFM, None),
            CRTFMN: GeckoByteStructAccessor(self.struct, CRTFMN, RTFMNH, None),
            TFMNHT: GeckoEnumStructAccessor(
                self.struct, TFMNHT, FMNHTB, None, UGTYIY, None, None, SAKQXP
            ),
            GTYIYW: GeckoEnumStructAccessor(
                self.struct, GTYIYW, TYIYWS, None, UGTYIY, None, None, SAKQXP
            ),
            YIYWSK: GeckoEnumStructAccessor(
                self.struct, YIYWSK, IYWSKW, None, UGTYIY, None, None, SAKQXP
            ),
            YWSKWI: GeckoEnumStructAccessor(
                self.struct, YWSKWI, WSKWIV, None, UGTYIY, None, None, SAKQXP
            ),
            SKWIVD: GeckoEnumStructAccessor(
                self.struct, SKWIVD, KWIVDN, None, UGTYIY, None, None, SAKQXP
            ),
            WIVDNQ: GeckoEnumStructAccessor(
                self.struct, WIVDNQ, IVDNQG, None, DNQGVU, None, None, SAKQXP
            ),
            NQGVUN: GeckoByteStructAccessor(self.struct, NQGVUN, QGVUNX, SAKQXP),
            GVUNXN: GeckoByteStructAccessor(self.struct, GVUNXN, VUNXNK, SAKQXP),
            UNXNKM: GeckoByteStructAccessor(self.struct, UNXNKM, NXNKML, SAKQXP),
            XNKMLO: GeckoByteStructAccessor(self.struct, XNKMLO, NKMLOI, SAKQXP),
            KMLOIJ: GeckoByteStructAccessor(self.struct, KMLOIJ, MLOIJU, SAKQXP),
            LOIJUG: GeckoByteStructAccessor(self.struct, LOIJUG, OIJUGS, SAKQXP),
            IJUGSE: GeckoEnumStructAccessor(
                self.struct, IJUGSE, JUGSEL, None, UGTYIY, None, None, SAKQXP
            ),
            UGSELH: GeckoEnumStructAccessor(
                self.struct, UGSELH, GSELHB, None, UGTYIY, None, None, SAKQXP
            ),
            SELHBQ: GeckoEnumStructAccessor(
                self.struct, SELHBQ, ELHBQN, None, UGTYIY, None, None, SAKQXP
            ),
            LHBQNR: GeckoEnumStructAccessor(
                self.struct, LHBQNR, HBQNRX, None, UGTYIY, None, None, SAKQXP
            ),
            BQNRXC: GeckoEnumStructAccessor(
                self.struct, BQNRXC, QNRXCH, None, UGTYIY, None, None, SAKQXP
            ),
            NRXCHW: GeckoEnumStructAccessor(
                self.struct, NRXCHW, RXCHWD, None, UGTYIY, None, None, SAKQXP
            ),
            XCHWDA: GeckoEnumStructAccessor(
                self.struct, XCHWDA, CHWDAF, None, UGTYIY, None, None, SAKQXP
            ),
            HWDAFI: GeckoEnumStructAccessor(
                self.struct, HWDAFI, WDAFIK, None, DAFIKJ, None, None, SAKQXP
            ),
            AFIKJP: GeckoEnumStructAccessor(
                self.struct, AFIKJP, FIKJPU, None, DAFIKJ, None, None, SAKQXP
            ),
            IKJPUN: GeckoByteStructAccessor(self.struct, IKJPUN, KJPUNR, SAKQXP),
            JPUNRJ: GeckoByteStructAccessor(self.struct, JPUNRJ, PUNRJZ, SAKQXP),
            UNRJZT: GeckoByteStructAccessor(self.struct, UNRJZT, NRJZTA, SAKQXP),
            RJZTAT: GeckoByteStructAccessor(self.struct, RJZTAT, JZTATD, SAKQXP),
            ZTATDZ: GeckoByteStructAccessor(self.struct, ZTATDZ, TATDZX, SAKQXP),
            ATDZXN: GeckoByteStructAccessor(self.struct, ATDZXN, TDZXNQ, SAKQXP),
            DZXNQT: GeckoByteStructAccessor(self.struct, DZXNQT, ZXNQTM, SAKQXP),
            XNQTMF: GeckoByteStructAccessor(self.struct, XNQTMF, NQTMFZ, SAKQXP),
            QTMFZD: GeckoByteStructAccessor(self.struct, QTMFZD, TMFZDG, SAKQXP),
        }



""" Gecko FILES/SFILE handlers """

import logging
import struct

from ...const import GeckoConstants
from .packet import GeckoPacketProtocolHandler

SFILE_VERB = b"SFILE"
FILES_VERB = b"FILES"

_LOGGER = logging.getLogger(__name__)


class GeckoConfigFileProtocolHandler(GeckoPacketProtocolHandler):
    @staticmethod
    def request(seq, **kwargs):
        return GeckoConfigFileProtocolHandler(
            content=b"".join([SFILE_VERB, struct.pack(">B", seq)]),
            timeout=2,
            retry_count=10,
            on_retry_failed=GeckoPacketProtocolHandler._default_retry_failed_handler,
            **kwargs,
        )

    @staticmethod
    def response(plateform_key, config_version, log_version, **kwargs):
        return GeckoConfigFileProtocolHandler(
            content=b"".join(
                [
                    FILES_VERB,
                    f",{plateform_key}_C{config_version:02}.xml,"
                    f"{plateform_key}_S{log_version:02}.xml".encode(
                        GeckoConstants.MESSAGE_ENCODING
                    ),
                ]
            ),
            **kwargs,
        )

    def __init__(self, **kwargs) -> None:
        super().__init__(**kwargs)
        self.plateform_key = self.config_version = self.log_version = None

    def can_handle(self, received_bytes: bytes, sender: tuple) -> bool:
        return received_bytes.startswith(SFILE_VERB) or received_bytes.startswith(
            FILES_VERB
        )

    def handle(self, received_bytes: bytes, sender: tuple) -> None:
        remainder = received_bytes[5:]
        if received_bytes.startswith(SFILE_VERB):
            self._sequence = struct.unpack(">B", remainder)[0]
            return  # Stay in the handler list

        # Otherwise must be FILES
        config = (
            received_bytes[6:]
            .decode(GeckoConstants.MESSAGE_ENCODING)
            .replace(".xml", "")
            .split(",")
        )
        # Split the string around the underscore
        gecko_pack_config = config[0].split("_")
        gecko_pack_log = config[1].split("_")

        if gecko_pack_config[0] != gecko_pack_log[0]:
            raise ValueError(
                f"Dissimilar platforms `{gecko_pack_config[0]}`"
                f" and `{gecko_pack_log[0]}`"
            )

        self.plateform_key = gecko_pack_config[0]
        if self.plateform_key == "MrSt":
            self.plateform_key = "MrSteam"
        self.config_version = int(gecko_pack_config[1][1:])
        self.log_version = int(gecko_pack_log[1][1:])
        self._should_remove_handler = True



"""GeckoUdpProtocolHandler base class"""

from __future__ import annotations
import logging
import time
import asyncio
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from .async_udp_protocol import GeckoAsyncUdpProtocol


from abc import ABC, abstractmethod

_LOGGER = logging.getLogger(__name__)


class GeckoUdpProtocolHandler(ABC):
    """
    Protocol handlers manage both sides of a specific conversation part with
    a remote end.

    The protocol is either initiated by a client or by a server, but either
    way a query should always met with a response from the remote end

    Both sides may instantiate listening handlers which will deal with
    unsolicited requests from remote clients and will respond so that the
    remote end knows the request was received and they may also send a query
    to the remote end, expecting a response to confirm receipt.

    A message sent will either make it to the destination, or it won't. Since
    this protocol is built on UDP, we have to cook our own timeout/retry
    mechanism to ensure delivery ... oddly this is precisely what TCP already
    does, no idea why this wasn't considered but hey-ho, this is all a bit of
    fun anyway!

    The base protocol handler will manage the lifetime of the handlers within
    the socket, and mechanisms are in place to allow retries to be handled
    with failure exit points available to allow clients to make class decisions
    or instance decisions, either by overridden methods, or by instance handlers

    """

    def __init__(self, **kwargs) -> None:
        # Send functionality
        self._send_bytes = kwargs.get("send_bytes", None)
        self.last_destination = None

        # Receive functionality
        self._on_handled = kwargs.get("on_handled", None)
        self._async_on_handled = kwargs.get("async_on_handled", None)

        # Lifetime functionality
        self._start_time = time.monotonic()
        self._timeout_in_seconds = kwargs.get("timeout", 0)
        self._retry_count = kwargs.get("retry_count", 0)
        self._on_retry_failed = kwargs.get("on_retry_failed", None)
        self._should_remove_handler = False

    ##########################################################################
    #
    #                         SEND FUNCTIONALITY
    #
    ##########################################################################
    @property
    def send_bytes(self) -> bytes:
        """The bytes to send to the remote end. Either uses the class instance
        data _send_bytes or can be overridden in a base class"""
        if self._send_bytes is None:
            raise NotImplementedError
        return self._send_bytes

    ##########################################################################
    #
    #                        RECEIVE FUNCTIONALITY
    #
    ##########################################################################

    @abstractmethod
    def can_handle(self, received_bytes: bytes, sender: tuple) -> bool:
        """Check if you can handle these bytes. If you return True, then your
        handle method will get called and no other handlers will be given a
        chance to process this data. If you return False then the search for a
        suitable handler will continue"""
        return False

    @abstractmethod
    def handle(self, received_bytes: bytes, sender: tuple) -> None:
        """Handle this data. This will only be called if you returned True
        from the `can_handle` function. If you wish to remove this handler
        from the system, then you should set the `should_remove_handler`
        member."""

    def handled(self, sender: tuple) -> None:
        """Base class implementation for when the data has been handled"""
        self._reset_timeout()
        assert self._async_on_handled is None
        if self._on_handled is not None:
            self._on_handled(self, sender)

    ##########################################################################
    #
    #                           ASYNC FUNCTIONALITY
    #
    ##########################################################################

    async def async_handle(self, received_bytes: bytes, sender: tuple) -> None:
        """Handle this data. This will only be called if you returned True
        from the `can_handle` function. If you wish to remove this handler
        from the system, then you should set the `should_remove_handler`
        member."""
        self.handle(received_bytes, sender)

    async def async_handled(self, sender: tuple) -> None:
        """Base class implementation for when the data has been handled"""
        self._reset_timeout()
        assert self._on_handled is None
        if self._async_on_handled is not None:
            await self._async_on_handled(self, sender)

    async def wait_for_response(self, protocol: GeckoAsyncUdpProtocol) -> bool:
        """Wait for a response that this command can handle, return True if handled,
        False if timed-out.

        This function doesn't respect the _on_handled functionality since its
        use is for inline async stuff"""
        assert self._timeout_in_seconds > 0
        while True:
            if protocol.queue.head is not None:
                data, sender = protocol.queue.head
                if self.can_handle(data, sender):
                    protocol.queue.pop()
                    await self.async_handle(data, sender)
                    self._reset_timeout()
                    return True

            if self.has_timedout:
                _LOGGER.debug("Handler %s timed out", self)
                return False

            await asyncio.sleep(0)

    async def consume(self, protocol: GeckoAsyncUdpProtocol) -> None:
        """Async coroutine to handle datagram."""

        assert self._timeout_in_seconds == 0
        while True:
            if protocol.queue.head is not None:
                data, sender = protocol.queue.head
                if self.can_handle(data, sender):
                    protocol.queue.pop()
                    await self.async_handle(data, sender)
                    await self.async_handled(sender)

            await asyncio.sleep(0)

            if self.should_remove_handler:
                _LOGGER.debug("%s will be removed, consume loop terminating", self)
                break

    ##########################################################################
    #
    #                         LIFETIME MANAGEMENT
    #
    ##########################################################################
    @property
    def age(self) -> float:
        return time.monotonic() - self._start_time

    @property
    def has_timedout(self) -> bool:
        return (
            self.age > self._timeout_in_seconds
            if self._timeout_in_seconds > 0
            else False
        )

    @property
    def should_remove_handler(self) -> bool:
        return self._should_remove_handler

    def _reset_timeout(self) -> None:
        self._start_time = time.monotonic()

    def retry(self, socket) -> bool:
        if self._retry_count == 0:
            return False
        self._retry_count -= 1
        _LOGGER.debug("Handler retry count %d", self._retry_count)
        self._reset_timeout()
        if socket is not None:
            # Queue another send
            socket.queue_send(self, self.last_destination)
        return True

    def loop(self, socket) -> None:
        """Executed each time around the socket loop"""
        if not self.has_timedout:
            return
        _LOGGER.debug("Handler has timed out")
        if self.retry(socket):
            return
        if self._on_retry_failed is not None:
            self._on_retry_failed(self, socket)

    @staticmethod
    def _default_retry_failed_handler(handler, socket) -> None:
        _LOGGER.debug("Default retry failed handler for %r being used", handler)
        handler._should_remove_handler = True

    # Pythonic methods
    def __repr__(self) -> str:
        return (
            f"{self.__class__.__name__}(send_bytes={self._send_bytes!r},"
            f" age={self.age}, has_timedout={self.has_timedout},"
            f" should_remove_handler={self.should_remove_handler},"
            f" timeout={self._timeout_in_seconds}s,"
            f" retry_count={self._retry_count}"
            f")"
        )
